@@ -1,25 +1,6 @@
 # Editing Settings of a Guest
 use strict;
 use warnings;
-require 'rbox_edit_gen_basic.pl';
-require 'rbox_edit_gen_advanced.pl';
-require 'rbox_edit_gen_description.pl';
-require 'rbox_edit_gen_encryption.pl';
-require 'rbox_edit_sys_mother.pl';
-require 'rbox_edit_sys_processor.pl';
-require 'rbox_edit_sys_advanced.pl';
-require 'rbox_edit_sys_acceleration.pl';
-require 'rbox_edit_sys_logo.pl';
-require 'rbox_edit_disp_screen.pl';
-require 'rbox_edit_disp_remote.pl';
-require 'rbox_edit_disp_capture.pl';
-require 'rbox_edit_storage.pl';
-require 'rbox_edit_audio.pl';
-require 'rbox_edit_network.pl';
-require 'rbox_edit_io_serial.pl';
-require 'rbox_edit_io_parallel.pl';
-require 'rbox_edit_usb.pl';
-require 'rbox_edit_shared.pl';
 our (%gui, %vmc);
 
 # Show the Edit dialog for a Guest
@@ -27,7 +8,7 @@ sub show_dialog_edit {
     undef(%vmc);
     my $gref = &getsel_list_guest();
     return if (!$$gref{IMachine}); # Do nothing if it was a group double clicked
-    &busy_window($gui{windowMain}, 0, 'watch');
+    &busy_window($gui{d}{Main}{win}, 0, 'watch');
     my $sref = &get_session($$gref{IMachine});
 
     if ($$sref{Lock} eq 'VM' or $$sref{Lock} eq 'Shared') {
@@ -35,6 +16,7 @@ sub show_dialog_edit {
         $vmc{IMachine} = $$sref{IMachine};
         $vmc{USBFilters} = IMachine_getUSBDeviceFilters($vmc{IMachine});
         $vmc{IFirmwareSettings} = IMachine_getFirmwareSettings($vmc{IMachine});
+        $vmc{INvramStore} = IMachine_getNonVolatileStore($vmc{IMachine});
         $vmc{IGraphicsAdapter} = IMachine_getGraphicsAdapter($vmc{IMachine});
         $vmc{IAudioSettings} = IMachine_getAudioSettings($vmc{IMachine});
         $vmc{IAudioAdapter} = IAudioSettings_getAdapter($vmc{IAudioSettings});
@@ -47,108 +29,105 @@ sub show_dialog_edit {
         $vmc{IHost} = IVirtualBox_getHost($gui{websn});
         $vmc{Name} = $$gref{Name};
         $vmc{SessionType} = $$sref{Type};
-        edit_tabchanged($gui{notebookEdit}, 0, $gui{notebookEdit}->get_current_page()); # Setup initial tab
+        edit_tabchanged($gui{d}{Edit}{notebook}, 0, $gui{d}{Edit}{notebook}->get_current_page()); # Setup initial tab
         &addrow_msg_log('Guest settings retrieved');
-        &busy_window($gui{windowMain}, 0);
+        &busy_window($gui{d}{Main}{win}, 0);
 
         # Here we need to change some widgets depending on the lock type
         # because some settings cannot be changed while the guest is locked
-        my $storagepage = $gui{notebookEdit}->get_nth_page(3);
-        my $iopage = $gui{notebookEdit}->get_nth_page(6);
-        my $genbasicpage = $gui{notebookEditGen}->get_nth_page(0);
-        my $sysmotherboard = $gui{notebookEditSys}->get_nth_page(0);
-        my $sysadvanced = $gui{notebookEditSys}->get_nth_page(2);
-        my $sysaccel = $gui{notebookEditSys}->get_nth_page(3);
-        my $sysbootpage = $gui{notebookEditSys}->get_nth_page(4);
-        my $dispvideopage = $gui{notebookEditDisp}->get_nth_page(0);
-        my $encryptionpage = $gui{notebookEditGen}->get_nth_page(3);
+        my $storagepage = $gui{d}{Edit}{notebook}->get_nth_page(3);
+        my $iopage = $gui{d}{Edit}{notebook}->get_nth_page(6);
+        my $genbasicpage = $gui{d}{Edit}{notebookGen}->get_nth_page(0);
+        my $sysmotherboard = $gui{d}{Edit}{notebookSys}->get_nth_page(0);
+        my $sysadvanced = $gui{d}{Edit}{notebookSys}->get_nth_page(2);
+        my $sysaccel = $gui{d}{Edit}{notebookSys}->get_nth_page(3);
+        my $sysbootpage = $gui{d}{Edit}{notebookSys}->get_nth_page(4);
+        my $dispvideopage = $gui{d}{Edit}{notebookDisp}->get_nth_page(0);
+        my $encryptionpage = $gui{d}{Edit}{notebookGen}->get_nth_page(3);
 
         if ($vmc{SessionType} eq 'WriteLock') {
-            $gui{dialogEdit}->set_title("Edit Settings - $$gref{Name}");
+            $gui{d}{Edit}{dialog}->set_title("Edit Settings - $$gref{Name}");
             $storagepage->set_sensitive(1);
             $iopage->set_sensitive(1);
             $genbasicpage->set_sensitive(1);
             # This can only be changed if there are no snapshots
             my $snapcount = IMachine_getSnapshotCount($vmc{IMachine});
             if ($snapcount) {
-                $gui{entryEditGenSnapFolder}->set_sensitive(0);
-                $gui{entryEditGenSnapFolder}->set_sensitive(0);
+                $gui{d}{Edit}{entryGenSnapfolder}->set_sensitive(0);
+                $gui{d}{Edit}{entryGenSnapfolder}->set_sensitive(0);
             }
             else {
-                $gui{entryEditGenSnapFolder}->set_sensitive(1);
-                $gui{buttonEditGenSnapFolder}->set_sensitive(1);
+                $gui{d}{Edit}{entryGenSnapfolder}->set_sensitive(1);
+                $gui{d}{Edit}{buttonGenSnapfolder}->set_sensitive(1);
             }
             $sysmotherboard->set_sensitive(1);
             $sysadvanced->set_sensitive(1);
             $sysaccel->set_sensitive(1);
             $sysbootpage->set_sensitive(1);
             $encryptionpage->set_sensitive(1);
-            $gui{hscaleEditSysProcessor}->set_sensitive(1);
-            $gui{checkbuttonEditSysPAE}->set_sensitive(1);
-            $gui{checkbuttonEditSysNestedVTX}->set_sensitive(1);
-            $gui{checkbuttonEditSysCPUHotPlug}->set_sensitive(1);
+            $gui{d}{Edit}{scaleSysProcessor}->set_sensitive(1);
+            $gui{d}{Edit}{checkSysPAE}->set_sensitive(1);
+            $gui{d}{Edit}{checkSysVTX}->set_sensitive(1);
+            $gui{d}{Edit}{checkSysHot}->set_sensitive(1);
             $dispvideopage->set_sensitive(1);
-            $gui{checkbuttonEditDispMultiple}->set_sensitive(1);
-            $gui{checkbuttonEditAudioEnable}->set_sensitive(1);
-            $gui{checkbuttonEditNetEnable}->set_sensitive(1);
-            $gui{entryEditNetMac}->set_sensitive(1);
-            $gui{buttonEditNetGenerateMac}->set_sensitive(1);
-            $gui{comboboxEditNetType}->set_sensitive(1);
-            $gui{radiobuttonEditUSB1}->set_sensitive(1);
-            $gui{radiobuttonEditUSB2}->set_sensitive(1);
-            $gui{radiobuttonEditUSB3}->set_sensitive(1);
-            $gui{checkbuttonEditUSBEnable}->set_sensitive(1);
-            $gui{labelEditOnline}->hide();
-            $gui{buttonEditCancel}->show();
+            $gui{d}{Edit}{checkDispRDPmultiple}->set_sensitive(1);
+            $gui{d}{Edit}{checkAudio}->set_sensitive(1);
+            $gui{d}{Edit}{checkNetwork}->set_sensitive(1);
+            $gui{d}{Edit}{entryNetworkMAC}->set_sensitive(1);
+            $gui{d}{Edit}{buttonNetworkMACgen}->set_sensitive(1);
+            $gui{d}{Edit}{cboxNetworkAdapter}->set_sensitive(1);
+            $gui{d}{Edit}{radioUSB1}->set_sensitive(1);
+            $gui{d}{Edit}{radioUSB2}->set_sensitive(1);
+            $gui{d}{Edit}{radioUSB3}->set_sensitive(1);
+            $gui{d}{Edit}{checkUSB}->set_sensitive(1);
         }
         else {
-            $gui{dialogEdit}->set_title("Online Edit Settings - $$gref{Name}");
+            $gui{d}{Edit}{dialog}->set_title("Online Edit Settings - $$gref{Name}");
             $storagepage->set_sensitive(0);
             $iopage->set_sensitive(0);
             $genbasicpage->set_sensitive(0);
-            $gui{entryEditGenSnapFolder}->set_sensitive(0);
-            $gui{buttonEditGenSnapFolder}->set_sensitive(0);
+            $gui{d}{Edit}{entryGenSnapfolder}->set_sensitive(0);
+            $gui{d}{Edit}{buttonGenSnapfolder}->set_sensitive(0);
             $sysmotherboard->set_sensitive(0);
             $sysadvanced->set_sensitive(0);
             $sysaccel->set_sensitive(0);
             $sysbootpage->set_sensitive(0);
             $encryptionpage->set_sensitive(0);
-            $gui{hscaleEditSysProcessor}->set_sensitive(0);
-            $gui{checkbuttonEditSysPAE}->set_sensitive(0);
-            $gui{checkbuttonEditSysNestedVTX}->set_sensitive(0);
-            $gui{checkbuttonEditSysCPUHotPlug}->set_sensitive(0);
+            $gui{d}{Edit}{scaleSysProcessor}->set_sensitive(0);
+            $gui{d}{Edit}{checkSysPAE}->set_sensitive(0);
+            $gui{d}{Edit}{checkSysVTX}->set_sensitive(0);
+            $gui{d}{Edit}{checkSysHot}->set_sensitive(0);
             $dispvideopage->set_sensitive(0);
-            $gui{checkbuttonEditDispMultiple}->set_sensitive(0);
-            $gui{checkbuttonEditAudioEnable}->set_sensitive(0);
-            $gui{checkbuttonEditNetEnable}->set_sensitive(0);
-            $gui{entryEditNetMac}->set_sensitive(0);
-            $gui{buttonEditNetGenerateMac}->set_sensitive(0);
-            $gui{comboboxEditNetType}->set_sensitive(0);
-            $gui{tableEditDispCapture}->set_sensitive(0);
-            $gui{checkbuttonEditUSBEnable}->set_sensitive(0);
-            $gui{radiobuttonEditUSB1}->set_sensitive(0);
-            $gui{radiobuttonEditUSB2}->set_sensitive(0);
-            $gui{radiobuttonEditUSB3}->set_sensitive(0);
-            $gui{labelEditOnline}->show();
-            $gui{buttonEditCancel}->hide();
+            $gui{d}{Edit}{checkDispRDPmultiple}->set_sensitive(0);
+            $gui{d}{Edit}{checkAudio}->set_sensitive(0);
+            $gui{d}{Edit}{checkNetwork}->set_sensitive(0);
+            $gui{d}{Edit}{entryNetworkMAC}->set_sensitive(0);
+            $gui{d}{Edit}{buttonNetworkMACgen}->set_sensitive(0);
+            $gui{d}{Edit}{cboxNetworkAdapter}->set_sensitive(0);
+            $gui{d}{Edit}{gridDispRecording}->set_sensitive(0);
+            $gui{d}{Edit}{checkUSB}->set_sensitive(0);
+            $gui{d}{Edit}{radioUSB1}->set_sensitive(0);
+            $gui{d}{Edit}{radioUSB2}->set_sensitive(0);
+            $gui{d}{Edit}{radioUSB3}->set_sensitive(0);
         }
 
         # Extradata doesn't get discarded on a cancel so we backup here and manually restore.
         my $floppya = IMachine_getExtraData($vmc{IMachine}, 'VBoxInternal/Devices/i82078/0/LUN#0/Config/Type');
         my $floppyb = IMachine_getExtraData($vmc{IMachine}, 'VBoxInternal/Devices/i82078/0/LUN#1/Config/Type');
 
-        my $response = $gui{dialogEdit}->run;
-        $gui{dialogEdit}->hide;
+        $gui{d}{Edit}{dialog}->show();
+        my $response = $gui{d}{Edit}{dialog}->run;
+        $gui{d}{Edit}{dialog}->hide;
 
         if ($response eq 'ok') {
             # We will apply encryption settings here as it's not possible to
             # do it in real time
-            if ($gui{checkbuttonEditGenEncryption}->get_state()) {
-                my $cipher = &getsel_combo($gui{comboboxEditGenEncryptionCipher}, 0);
+            if ($gui{d}{Edit}{checkGenEncryption}->get_state()) {
+                my $cipher = &getsel_combo($gui{d}{Edit}{cboxGenCiper}, 1);
                 if ($cipher ne 'Unchanged') {
 
-                    my $passwd1 = $gui{entryEditGenEncryptionPass}->get_text();
-                    my $passwd2 = $gui{entryEditGenEncryptionPassCon}->get_text();
+                    my $passwd1 = $gui{d}{Edit}{entryGenPass}->get_text();
+                    my $passwd2 = $gui{d}{Edit}{entryGenConfirm}->get_text();
 
                     if ($passwd1) {
                         if ($passwd1 ne $passwd2) { &show_err_msg('encdiskpasswd'); }
@@ -192,7 +171,7 @@ sub show_dialog_edit {
         undef(%vmc);
         &flush_pagecache();
         $gui{miAttachFloppy} = $gui{miAttachDVD} = $gui{miAttachHD} = $gui{menuAttachFloppy} =
-        $gui{menuAttachDVD} = $gui{menuAttachHD} = $gui{menuAttachAdd} = $gui{menuUSB} = undef; # These must be freed
+        $gui{menuAttachDVD} = $gui{menuAttachHD} = $gui{menuAttachAdd} = $gui{menu}{USB} = undef; # These must be freed
     }
     else { &show_err_msg('settings'); }
 
@@ -207,17 +186,45 @@ sub show_dialog_edit {
     sub edit_tabchanged {
         my ($widget, $focus, $page) = @_;
 
-        if ($pagecache{mainedit}{$page}) { } # Do Nothing, Page is Cached
-        elsif ($page == 0) { &edit_gen_tabchanged($gui{notebookEditGen}, 0, $gui{notebookEditGen}->get_current_page()); } # Setup initial tab as it'll aleady be open
-        elsif ($page == 1) { &edit_sys_tabchanged($gui{notebookEditSys}, 0, $gui{notebookEditSys}->get_current_page()); } # Setup initial tab as it'll aleady be open
-        elsif ($page == 2) { &edit_disp_tabchanged($gui{notebookEditDisp}, 0, $gui{notebookEditDisp}->get_current_page()); } # Setup initial tab as it'll aleady be open
-        elsif ($page == 3) { &init_edit_storage(); }
-        elsif ($page == 4) { &init_edit_audio(); }
-        elsif ($page == 5) { &init_edit_network(); }
-        elsif ($page == 6) { &edit_io_tabchanged($gui{notebookEditIO}, 0, $gui{notebookEditIO}->get_current_page()); } # Setup initial tab as it'll aleady be open
-        elsif ($page == 7) { &init_edit_usb(); }
-        elsif ($page == 8) { &init_edit_shared(); }
-        $pagecache{mainedit}{$page} = 1;
+        if ($page == 0) { &edit_gen_tabchanged($gui{d}{Edit}{notebookGen}, 0, $gui{d}{Edit}{notebookGen}->get_current_page()); } # Setup initial tab as it'll aleady be open
+        elsif ($page == 1) { &edit_sys_tabchanged($gui{d}{Edit}{notebookSys}, 0, $gui{d}{Edit}{notebookSys}->get_current_page()); } # Setup initial tab as it'll aleady be open
+        elsif ($page == 2) { &edit_disp_tabchanged($gui{d}{Edit}{notebookDisp}, 0, $gui{d}{Edit}{notebookDisp}->get_current_page()); } # Setup initial tab as it'll aleady be open
+        elsif ($page == 3) {
+            # There's no notebook on the page to cache, cache it here
+            if (!$pagecache{stor}{0}) {
+                &init_edit_storage();
+                $pagecache{stor}{0} = 1;
+            }
+        }
+        elsif ($page == 4) {
+            # There's no notebook on the page to cache, cache it here
+            if (!$pagecache{audio}{0}) {
+                &init_edit_audio();
+                $pagecache{audio}{0} = 1;
+            }
+        }
+        elsif ($page == 5) {
+            # There's no notebook on the page to cache, cache it here
+            if (!$pagecache{net}{0}) {
+                &init_edit_network();
+                $pagecache{net}{0} = 1;
+            }
+        }
+        elsif ($page == 6) { &edit_io_tabchanged($gui{d}{Edit}{notebookIOPorts}, 0, $gui{d}{Edit}{notebookIOPorts}->get_current_page()); } # Setup initial tab as it'll aleady be open
+        elsif ($page == 7) {
+            # There's no notebook on the page to cache, cache it here
+            if (!$pagecache{net}{0}) {
+                &init_edit_usb();
+                $pagecache{net}{0} = 1;
+            }
+        }
+        elsif ($page == 8) {
+            # There's no notebook on the page to cache, cache it here
+            if (!$pagecache{net}{0}) {
+                &init_edit_shared();
+                $pagecache{net}{0} = 1;
+            }
+        }
     }
 
     sub edit_gen_tabchanged {
