@@ -10,7 +10,7 @@ our (%gui, %vmc);
 my %cap_opts;
 
 sub init_edit_disp_capture {
-    &set_pointer($gui{dialogEdit}, 'watch');
+    &set_pointer($gui{d}{Edit}{dialog}, 'watch');
     my $cap_optstr = IRecordingScreenSettings_getOptions($vmc{IRecordingScreenSettings});
     undef(%cap_opts); # We must clear the hash each time as old options from a pervious edit might get left
 
@@ -27,85 +27,85 @@ sub init_edit_disp_capture {
         $cap_opts{$l}=$r;
     }
 
-    $gui{tableEditDispCapture}->set_sensitive($gui{checkbuttonEditDispCapture}->get_active()) if ($vmc{SessionType} eq 'WriteLock'); # Ghost/Unghost other widgets based on capture enabled
-    $gui{sbEditDispCaptureFPS}->set_value(IRecordingScreenSettings_getVideoFPS($vmc{IRecordingScreenSettings}));
-    $gui{sbEditDispCaptureQuality}->set_value(IRecordingScreenSettings_getVideoRate($vmc{IRecordingScreenSettings}));
-    $gui{checkbuttonEditDispCapture}->set_active(&bl(IRecordingSettings_getEnabled($vmc{IRecordingSettings}))); # We only support screen 0, this is the master switch. We also toggle the switch for screen 0
-    $gui{entryEditDispCapturePath}->set_text(IRecordingScreenSettings_getFilename($vmc{IRecordingScreenSettings}));
+    $gui{d}{Edit}{gridDispRecording}->set_sensitive($gui{d}{Edit}{checkDispRecording}->get_active()) if ($vmc{SessionType} eq 'WriteLock'); # Ghost/Unghost other widgets based on capture enabled
+    $gui{d}{Edit}{sbDispRecordingrate}->set_value(IRecordingScreenSettings_getVideoFPS($vmc{IRecordingScreenSettings}));
+    $gui{d}{Edit}{sbDispRecordingVidqual}->set_value(IRecordingScreenSettings_getVideoRate($vmc{IRecordingScreenSettings}));
+    $gui{d}{Edit}{checkDispRecording}->set_active(&bl(IRecordingSettings_getEnabled($vmc{IRecordingSettings}))); # We only support screen 0, this is the master switch. We also toggle the switch for screen 0
+    $gui{d}{Edit}{entryDispRecordingpath}->set_text(IRecordingScreenSettings_getFilename($vmc{IRecordingScreenSettings}));
 
-    if ($cap_opts{ac_enabled} eq 'false' and $cap_opts{vc_enabled} eq 'true') { $gui{comboboxEditDispCaptureMode}->set_active(1); }
-    elsif ($cap_opts{ac_enabled} eq 'true' and $cap_opts{vc_enabled} eq 'false') { $gui{comboboxEditDispCaptureMode}->set_active(2); }
-    else  { $gui{comboboxEditDispCaptureMode}->set_active(0); }
+    if ($cap_opts{ac_enabled} eq 'false' and $cap_opts{vc_enabled} eq 'true') { $gui{d}{Edit}{cboxDispRecordingmode}->set_active(2); }
+    elsif ($cap_opts{ac_enabled} eq 'true' and $cap_opts{vc_enabled} eq 'false') { $gui{d}{Edit}{cboxDispRecordingmode}->set_active(1); }
+    else  { $gui{d}{Edit}{cboxDispRecordingmode}->set_active(0); }
 
-    &combobox_set_active_text($gui{comboboxEditDispAudioQuality}, $cap_opts{ac_profile}, 0);
+    &combobox_set_active_text($gui{d}{Edit}{cboxDispAudqual}, $cap_opts{ac_profile}, 1);
     my ($w, $h) = (IRecordingScreenSettings_getVideoWidth($vmc{IRecordingScreenSettings}), IRecordingScreenSettings_getVideoHeight($vmc{IRecordingScreenSettings}));
-    my $fsiter = $gui{liststoreDispCaptureSize}->get_iter_first(); # Set the framesize combobox to the active position depending on associated spinboxes
+    my $fsiter = $gui{d}{Edit}{lstoreDispRecordingsize}->get_iter_first(); # Set the framesize combobox to the active position depending on associated spinboxes
     my $fspos = 0;
-    $gui{comboboxEditDispCaptureSize}->set_active(0);
+    $gui{d}{Edit}{cboxDispRecordingsize}->set_active(0);
 
-    while (defined($fsiter) and $gui{liststoreDispCaptureSize}->iter_is_valid($fsiter)) {
-        if ($w == $gui{liststoreDispCaptureSize}->get_value($fsiter, 1) and $h == $gui{liststoreDispCaptureSize}->get_value($fsiter, 2)) {
-            $gui{comboboxEditDispCaptureSize}->set_active($fspos);
+    while (defined($fsiter) and $gui{d}{Edit}{lstoreDispRecordingsize}->iter_is_valid($fsiter)) {
+        if ($w == $gui{d}{Edit}{lstoreDispRecordingsize}->get_value($fsiter, 1) and $h == $gui{d}{Edit}{lstoreDispRecordingsize}->get_value($fsiter, 2)) {
+            $gui{d}{Edit}{cboxDispRecordingsize}->set_active($fspos);
             last;
         }
         else {
             $fspos++;
-            $gui{liststoreDispCaptureSize}->iter_next($fsiter); # Automatically modifies the iter
-            $gui{sbEditDispCaptureSizeW}->set_value($w);
-            $gui{sbEditDispCaptureSizeH}->set_value($h);
+            $gui{d}{Edit}{lstoreDispRecordingsize}->iter_next($fsiter); # Automatically modifies the iter
+            $gui{d}{Edit}{sbDispRecordingw}->set_value($w);
+            $gui{d}{Edit}{sbDispRecordingh}->set_value($h);
         }
     }
-    &set_pointer($gui{dialogEdit});
+    &set_pointer($gui{d}{Edit}{dialog});
 }
 
 # Save the preferred capture width
 sub disp_cap_size_w {
     # Avoid triggering if not in WriteLock mode. Cannot be changed when guest is running
-    IRecordingScreenSettings_setVideoWidth($vmc{IRecordingScreenSettings}, $gui{sbEditDispCaptureSizeW}->get_value_as_int()) if ($vmc{SessionType} eq 'WriteLock');
+    IRecordingScreenSettings_setVideoWidth($vmc{IRecordingScreenSettings}, $gui{d}{Edit}{sbDispRecordingw}->get_value_as_int()) if ($vmc{SessionType} eq 'WriteLock');
     return 0;
 }
 
 # Save the preferred capture height
 sub disp_cap_size_h {
     # Avoid triggering if not in WriteLock mode. Cannot be changed when guest is running
-    IRecordingScreenSettings_setVideoHeight($vmc{IRecordingScreenSettings}, $gui{sbEditDispCaptureSizeH}->get_value_as_int()) if ($vmc{SessionType} eq 'WriteLock');
+    IRecordingScreenSettings_setVideoHeight($vmc{IRecordingScreenSettings}, $gui{d}{Edit}{sbDispRecordingh}->get_value_as_int()) if ($vmc{SessionType} eq 'WriteLock');
     return 0;
 }
 
 # The number of FPS to capture
 sub disp_cap_fps {
     # Avoid triggering if not in WriteLock mode. Cannot be changed when guest is running
-    IRecordingScreenSettings_setVideoFPS($vmc{IRecordingScreenSettings}, $gui{sbEditDispCaptureFPS}->get_value_as_int()) if ($vmc{SessionType} eq 'WriteLock');
+    IRecordingScreenSettings_setVideoFPS($vmc{IRecordingScreenSettings}, $gui{d}{Edit}{sbDispRecordingrate}->get_value_as_int()) if ($vmc{SessionType} eq 'WriteLock');
     return 0;
 }
 
 # The quality of the recorded video in kbps
 sub disp_cap_vidrate {
     # Avoid triggering if not in WriteLock mode. Cannot be changed when guest is running
-    IRecordingScreenSettings_setVideoRate($vmc{IRecordingScreenSettings}, $gui{sbEditDispCaptureQuality}->get_value_as_int()) if ($vmc{SessionType} eq 'WriteLock');
+    IRecordingScreenSettings_setVideoRate($vmc{IRecordingScreenSettings}, $gui{d}{Edit}{sbDispRecordingVidqual}->get_value_as_int()) if ($vmc{SessionType} eq 'WriteLock');
     return 0;
 }
 
 # Sets the quality of the audio
 sub disp_cap_audio_quality {
     my ($widget) = @_;
-    $cap_opts{ac_profile} = &getsel_combo($widget, 0);
+    $cap_opts{ac_profile} = &getsel_combo($widget, 1);
     &disp_cap_send_opts();
 }
 
 # The the location of the video/audio capture file
 sub disp_cap_path {
     # Avoid triggering if not in WriteLock mode. Cannot be changed when guest is running. API automatically apends the file extension
-    IRecordingScreenSettings_setFilename($vmc{IRecordingScreenSettings}, $gui{entryEditDispCapturePath}->get_text()) if ($vmc{SessionType} eq 'WriteLock');
+    IRecordingScreenSettings_setFilename($vmc{IRecordingScreenSettings}, $gui{d}{Edit}{entryDispRecordingpath}->get_text()) if ($vmc{SessionType} eq 'WriteLock');
     return 0;
 }
 
 # Enable or Disable capturing
 sub disp_toggleCapture {
-    my $state = $gui{checkbuttonEditDispCapture}->get_active();
+    my $state = $gui{d}{Edit}{checkDispRecording}->get_active();
     IRecordingSettings_setEnabled($vmc{IRecordingSettings}, $state); # Set the master recording setting
     IRecordingScreenSettings_setEnabled($vmc{IRecordingScreenSettings}, $state); # Set it specific to screen 0. We only support screen 0 at the moment
-    $gui{tableEditDispCapture}->set_sensitive($state) if ($vmc{SessionType} eq 'WriteLock'); # Don't enable other widgets unless in WriteLock Mode
+    $gui{d}{Edit}{gridDispRecording}->set_sensitive($state) if ($vmc{SessionType} eq 'WriteLock'); # Don't enable other widgets unless in WriteLock Mode
 }
 
 # If the combobox changes, update the associated spinboxes
@@ -113,15 +113,15 @@ sub disp_cap_size {
     my ($widget) = @_;
     my ($w, $h) = (&getsel_combo($widget,1), &getsel_combo($widget,2));
     unless ($w < 17 and $h < 17) { # Min width/height is 16
-        $gui{sbEditDispCaptureSizeW}->set_value($w);
-        $gui{sbEditDispCaptureSizeH}->set_value($h);
+        $gui{d}{Edit}{sbDispRecordingw}->set_value($w);
+        $gui{d}{Edit}{sbDispRecordingh}->set_value($h);
     }
 }
 
 # Sets the recording mode. (ie Video+Audio, Video Only, Audo Only)
 sub disp_cap_mode {
     my ($widget) = @_;
-    my $mode = &getsel_combo($widget, 0);
+    my $mode = &getsel_combo($widget, 1);
 
     if ($mode eq 'video') {
         $cap_opts{vc_enabled}='true';
