@@ -4,7 +4,7 @@ use warnings;
 our (%gui, %vmc);
 
 sub init_edit_shared {
-    &set_pointer($gui{dialogEdit}, 'watch');
+    &set_pointer($gui{d}{Edit}{dialog}, 'watch');
     # Ie only permanent shares
     if ($vmc{SessionType} eq 'WriteLock') {
         $gui{d}{SharedFolders}{checkPermanent}->set_active(1);
@@ -17,14 +17,14 @@ sub init_edit_shared {
 
     &fill_list_edit_shared($vmc{IMachine});
     IMachine_saveSettings($vmc{IMachine});
-    &set_pointer($gui{dialogEdit});
+    &set_pointer($gui{d}{Edit}{dialog});
 }
 
 # Show the dialog for adding a shared folder
 sub show_dialog_shared {
     my ($widget) = @_;
 
-    if ($widget ne $gui{buttonEditSharedAdd}) {
+    if ($widget ne $gui{d}{Edit}{buttonSharedAdd}) {
         my $sref = &getsel_list_editshared();
         $gui{d}{SharedFolders}{entryPath}->set_text($$sref{Folder});
         $gui{d}{SharedFolders}{entryName}->set_text($$sref{Name});
@@ -34,16 +34,16 @@ sub show_dialog_shared {
     }
 
     do {
-        $gui{d}{SharedFolders}->show_all;
-        my $response = $gui{d}{SharedFolders}->run();
+        $gui{d}{SharedFolders}{dialog}->show_all;
+        my $response = $gui{d}{SharedFolders}{dialog}->run();
 
         if ($response eq 'ok') {
             # No validation needed for other entries
             if (!$gui{d}{SharedFolders}{entryPath}->get_text()) { &show_err_msg('invalidpath', '(Folder Path)'); }
             elsif (!$gui{d}{SharedFolders}{entryName}->get_text()) { &show_err_msg('invalidname', '(Folder Name)'); }
             else {
-                $gui{d}{SharedFolders}->hide;
-                &share_remove($widget, $gui{treeviewEditShared}) if ($widget ne $gui{buttonEditSharedAdd});
+                $gui{d}{SharedFolders}{dialog}->hide;
+                &share_remove($widget, $gui{d}{Edit}{treeviewShared}) if ($widget ne $gui{d}{Edit}{buttonSharedAdd});
 
                 if ($gui{d}{SharedFolders}{checkPermanent}->get_active()) {
                     IMachine_createSharedFolder($vmc{IMachine}, $gui{d}{SharedFolders}{entryName}->get_text(),
@@ -64,9 +64,9 @@ sub show_dialog_shared {
                 IMachine_saveSettings($vmc{IMachine});
             }
         }
-        else { $gui{d}{SharedFolders}->hide; }
+        else { $gui{d}{SharedFolders}{dialog}->hide; }
 
-    } until (!$gui{d}{SharedFolders}->get_visible());
+    } until (!$gui{d}{SharedFolders}{dialog}->get_visible());
 }
 
 # Deletes a share and handles both permanent and transient
