@@ -124,6 +124,9 @@ our (%gui);
                 startguest         => ['Failed to Start Guest',
                                        '',
                                        'error'],
+                noefivariables     => ['Creating UEFI VMRAM File',
+                                       'As this guest is now using EFI, a new UEFI VMRAM file needs to be created.',
+                                       'info'],
                 nodiraccess        => ['Permission Denied or Non-Existant Folder',
                                        'If access is required, verify the folder exists and its permissions are ' .
                                        'correct. Ensure the VirtualBox web service is running as the correct user.',
@@ -136,7 +139,7 @@ our (%gui);
                                        'This version of RemoteBox is not supported with the version of VirtualBox on the' .
                                        " server.\nVisit http://remotebox.knobgoblin.org.uk to download a compatible version of RemoteBox.\n" .
                                        "RemoteBox will continue, but you may experience problems due to incompatibilities.\n\n" .
-                                       'Supported VirtualBox Version: 7.0.x',
+                                       'Supported VirtualBox Version: 7.1.x',
                                        'warning'],
                 webservice         => ['VirtualBox Returned an Error',
                                        '',
@@ -144,9 +147,9 @@ our (%gui);
 
     sub show_err_msg {
         my ($key, $append) = @_;
-        my $dialog = $gui{d}{errorMessageDialog};
+        my $dialog = $gui{d}{Error}{dialog};
         my ($title, $body, $type) = @{ $err{$key} };
-        $dialog = $gui{d}{warningMessageDialog} if ($type eq 'warning');
+        $dialog = $gui{d}{Warning}{dialog} if ($type eq 'warning');
         $body .= "\n$append" if ($append);
         &addrow_msg_log("Error Dialog:    $title:    $body");
         $dialog->set_markup("<big><b>$title</b></big>");
@@ -167,10 +170,10 @@ sub show_invalid_object_msg {
                "but will require you to reconnect.\n\nAdditional:\n";
     $body .= $append if ($append);
     &addrow_msg_log("Error Dialog:    Invalid Object Reference:    $body");
-    $gui{$gui{d}{invalidobjectMessage}}->format_secondary_markup($body);
-
-    my $response = $gui{$gui{d}{invalidobjectMessage}}->run;
-    $gui{$gui{d}{invalidobjectMessage}}->hide;
+    $gui{d}{InvalidObj}{dialog}->format_secondary_markup($body);
+    $gui{d}{InvalidObj}{dialog}->show_all();
+    my $response = $gui{d}{InvalidObj}{dialog}->run();
+    $gui{d}{InvalidObj}{dialog}->hide();
     return $response;
 }
 
