@@ -263,7 +263,7 @@ sub get_icontroller_attrs {
                           {num => 3, desc => 'Remmina',                    command => 'remmina rdp://%U@%h:%p'},
                           {num => 4, desc => 'Rdesktop',                   command => 'rdesktop -g %Xx%Y -r sound:local -r clipboard:PRIMARYCLIPBOARD -T "%n - RemoteBox" %h:%p'},
                           {num => 5, desc => 'KRDC',                       command => 'krdc rdp://%h:%p'},
-                          {num => 6, desc => 'Windows RDP Client (mstsc)', command => 'mstsc /w:%X /h:%Y /v:%h:%p'});
+                          {num => 6, desc => 'Windows RDP Client (mstsc)', command => 'mstsc.exe /w:%X /h:%Y /v:%h:%p'});
 
     my @vnc_preset_tbl = ({num => 1, desc => 'TigerVNC (vncviewer)', command => 'vncviewer -Shared -AcceptClipboard -SetPrimary -SendClipboard -SendPrimary -RemoteResize -DesktopSize %Xx%Y  %h::%p'},
                           {num => 2, desc => 'Remmina',              command => 'remmina vnc://%h:%p'},
@@ -396,4 +396,28 @@ sub generate_uuid {
            substr($digest, 20);
 }
 
+# Return the lowest ip4 address
+sub ip4_lowest {
+    my ($ip4, $netmask) = @_;
+    my $network_address = inet_aton($ip4) & inet_aton($netmask);
+    return inet_ntoa($network_address);
+}
+
+# Return the highest ip4 address, minus 1 for the typical broadcast
+sub ip4_highest {
+    my ($ip4, $netmask) = @_;
+    my $inverted_netmask = pack("N", ~unpack("N", inet_aton($netmask)));
+    my $high_address = (inet_aton($ip4) | $inverted_netmask);
+    return &ip4_add(inet_ntoa($high_address), -1);
+}
+
+# Inc / Dec an IP4 address by a certain amount
+sub ip4_add {
+    my ($ip4, $val) = @_;
+    my $ip_int = unpack("N", inet_aton($ip4)) + $val;
+    return inet_ntoa(pack("N", $ip_int));
+}
+
+
+
 1;
