@@ -7,9 +7,14 @@ my %cmdopts=();
 $endpoint = 'http://localhost:18083';
 $fault = sub{}; # Do nothing with faults until connected
 &rbprefs_get(); # Retrieve and set preferences
-&restore_window_pos('windowMain');
+&restore_window_pos($gui{d}{Main}{win});
 &addrow_msg_log("Welcome to $gui{appname} $gui{appver}");
 getopts("H:u:p:h", \%cmdopts);
+# Set Disconnected State
+&sens_unselected();
+&sens_connect(0);
+&clr_list_guest();
+&clr_vhost(); # Clear vhost so values are not retained on subsequent connections
 
 if($cmdopts{h}) {
     print STDERR <<USAGE;
@@ -27,10 +32,11 @@ USAGE
 elsif ($cmdopts{H}) { &show_dialog_connect('CMDAUTO'); } # Command line parameter based login
 elsif ($prefs{AUTOCONNPROF}) { &show_dialog_connect('PROFAUTO'); } # Profile based automatic login
 $0 = 'RemoteBox VirtualBox Client';
+$gui{d}{Main}{win}->show_all();
 Gtk3->main;
 
 sub quit_remotebox {
-    &save_window_pos('windowMain'); # Also saves the main preferences
+    &save_window_pos($gui{d}{Main}{win}); # Also saves the main preferences
     &virtualbox_logoff();
     Gtk3->main_quit;
 }
@@ -64,7 +70,7 @@ sub virtualbox_logoff {
     # execute their cancel operations
     if ($closewin) {
         foreach my $win (Gtk3::Window->list_toplevels()) {
-            next if ($win eq $gui{windowMain});
+            next if ($win eq $gui{d}{Main}{win});
             $win->hide;
         }
     }
@@ -131,11 +137,12 @@ sub show_dialog_connect {
     }
     else { # Normal GUI login
         $gui{d}{Connect}{cboxProfile}->set_active(-1); # We don't want a current active
-        $response = $gui{d}{Connect}->run;
-        $gui{d}{Connect}->hide;
+        $gui{d}{Connect}{dialog}->show_all();
+        $response = $gui{d}{Connect}{dialog}->run();
+        $gui{d}{Connect}{dialog}->hide();
     }
 
-    $gui{d}{Connect}->get_display->flush;
+    $gui{d}{Connect}{dialog}->get_display->flush;
 
     if ($response eq 'ok') {
         my $url = &strim($gui{d}{Connect}{entryURL}->get_text());
@@ -160,13 +167,13 @@ sub show_dialog_connect {
                 &show_err_msg('vboxver', "Detected VirtualBox Version: $ver") if ($ver !~ m/^7.1/);
                 my $vhost = &vhost();
 
-                if ($$vhost{vrdeextpack} =~ m/Oracle VirtualBox Extension Pack/i) { $gui{toolbuttonRemoteDisplay}->set_label('_Guest Display (RDP)'); }
+                if ($$vhost{vrdeextpack} =~ m/Oracle VirtualBox Extension Pack/i) { $gui{d}{Main}{buttonDisplay}->set_label('_Guest Display (RDP)'); }
                 elsif ($$vhost{vrdeextpack} =~ m/vnc/i) {
-                    $gui{toolbuttonRemoteDisplay}->set_label('_Guest Display (VNC)');
+                    $gui{d}{Main}{buttonDisplay}->set_label('_Guest Display (VNC)');
                     &addrow_msg_log('Warning: The Oracle VirtualBox Extension Pack is not installed.', '* This pack is only available for Linux, Windows, Solaris and MacOS ', '* Features which require this extension pack will be non-functional or unavailable');
                 }
                 else {
-                    $gui{toolbuttonRemoteDisplay}->set_label('Guest Display Unavailable');
+                    $gui{d}{Main}{buttonDisplay}->set_label('Guest Display Unavailable');
                     &show_err_msg('noextensions');
                 }
 
@@ -191,7 +198,7 @@ sub show_progress_window {
     my $resultcode = 0;
     my $timer = 0;
     $decal ? $gui{d}{Progress}{img}->set_from_pixbuf($decal) : $gui{d}{Progress}{img}->set_from_pixbuf($gui{pb}{ProgressSettings});
-    $gui{d}{Progress}->set_title($msg);
+    $gui{d}{Progress}{dialog}->set_title($msg);
     $gui{d}{Progress}{label}->set_text('Please Wait...'); # Reset text so its not cached from a previous call
     $gui{d}{Progress}{bar}->set_text(''); # Reset text so its not cached from a previous call
     $gui{d}{Progress}{bar}->set_fraction(0); # Reset fraction back to 0
@@ -210,7 +217,7 @@ sub show_progress_window {
                 $gui{d}{Progress}{bar}->set_fraction(1.00);
                 $gui{d}{Progress}{bar}->set_text('100%');
                 $resultcode = IProgress_getResultCode($IProgress);
-                $gui{d}{Progress}->response('ok');
+                $gui{d}{Progress}{dialog}->response('ok');
                 return 0;
             }
             else {
@@ -225,8 +232,8 @@ sub show_progress_window {
             }
         });
 
-    my $response = $gui{d}{Progress}->run();
-    $gui{d}{Progress}->hide();
+    my $response = $gui{d}{Progress}{dialog}->run();
+    $gui{d}{Progress}{dialog}->hide();
     Glib::Source->remove($timer) if ($timer);
     IProgress_cancel($IProgress) if ($response ne 'ok');
     Gtk3::main_iteration while Gtk3::events_pending;
@@ -235,16 +242,17 @@ sub show_progress_window {
 
 # Shows the about dialog
 sub show_dialog_about {
-    $gui{d}{About}->run;
-    $gui{d}{About}->hide;
+    $gui{d}{About}{dialog}->run;
+    $gui{d}{About}{dialog}->hide;
 }
 
 # Shows the custom video hint dialog
 sub show_dialog_videohint {
     $gui{d}{CustomVideo}{sbVideoW}->set_value($prefs{AUTOHINTDISPX});
     $gui{d}{CustomVideo}{sbVideoH}->set_value($prefs{AUTOHINTDISPY});
-    my $response = $gui{d}{CustomVideo}->run;
-    $gui{d}{CustomVideo}->hide;
+    $gui{d}{CustomVideo}{dialog}->show_all();
+    my $response = $gui{d}{CustomVideo}{dialog}->run();
+    $gui{d}{CustomVideo}{dialog}->hide();
 
     if ($response eq 'ok') { return [$gui{d}{CustomVideo}{sbVideoW}->get_value_as_int(), $gui{d}{CustomVideo}{sbVideoH}->get_value_as_int(), &getsel_combo($gui{d}{CustomVideo}{cboxVideoDepth}, 1)] }
     else { return [0,0,0]; }
@@ -253,17 +261,19 @@ sub show_dialog_videohint {
 # Shows a dialog with basic information about the VirtualBox server
 sub show_dialog_serverinfo {
     &fill_list_serverinfo();
-    $gui{d}{ServerInfo}->run;
-    $gui{d}{ServerInfo}->hide;
+    $gui{d}{ServerInfo}{dialog}->show_all();
+    $gui{d}{ServerInfo}{dialog}->run();
+    $gui{d}{ServerInfo}{dialog}->hide();
 }
 
 # Displays a dialog with the contents of the logs for a specific guest
 sub show_dialog_log {
     my $gref = &getsel_list_guest();
     &fill_list_log($$gref{IMachine});
-    $gui{d}{GuestLog}->set_title("$$gref{Name} Guest Logs");
-    $gui{d}{GuestLog}->run;
-    $gui{d}{GuestLog}->hide;
+    $gui{d}{GuestLog}{dialog}->set_title("$$gref{Name} Guest Logs");
+    $gui{d}{GuestLog}{dialog}->show_all();
+    $gui{d}{GuestLog}{dialog}->run();
+    $gui{d}{GuestLog}{dialog}->hide();
 }
 
 sub refresh_guest_logs {
@@ -275,11 +285,11 @@ sub refresh_guest_logs {
 sub guest_log_save {
     my $gref = &getsel_list_guest();
     my $lognum = $gui{d}{GuestLog}{notebookLog}->get_current_page(); # We choose the log number by the page number
-    $gui{d}{LogFileChooser}->set_current_name("$$gref{Name}_log$lognum" . '.txt');
-    $gui{d}{LogFileChooser}->set_current_folder($ENV{HOME}) if ($ENV{HOME});
-    my $response = $gui{d}{LogFileChooser}->run();
-    $gui{d}{LogFileChooser}->hide();
-    my $filename = $gui{d}{LogFileChooser}->get_filename();
+    $gui{d}{LogFileChooser}{dialog}->set_current_name("$$gref{Name}_log$lognum" . '.txt');
+    $gui{d}{LogFileChooser}{dialog}->set_current_folder($ENV{HOME}) if ($ENV{HOME});
+    my $response = $gui{d}{LogFileChooser}{dialog}->run();
+    $gui{d}{LogFileChooser}{dialog}->hide();
+    my $filename = $gui{d}{LogFileChooser}{dialog}->get_filename();
 
     if ($response eq 'ok' and $filename) {
         if (open(my $guest_log_fh, '>', $filename)) {
@@ -298,20 +308,20 @@ sub guest_log_save {
 }
 
 # Save the contents of the message log into a file
-sub msg_log_save {
-    $gui{d}{LogFileChooser}->set_current_name('remotebox-message-log.txt');
-    $gui{d}{LogFileChooser}->set_current_folder($ENV{HOME}) if ($ENV{HOME});
-    my $response = $gui{d}{LogFileChooser}->run();
-    $gui{d}{LogFileChooser}->hide();
-    my $filename = $gui{d}{LogFileChooser}->get_filename();
+sub save_msg_log {
+    $gui{d}{LogFileChooser}{dialog}->set_current_name('remotebox-message-log.txt');
+    $gui{d}{LogFileChooser}{dialog}->set_current_folder($ENV{HOME}) if ($ENV{HOME});
+    my $response = $gui{d}{LogFileChooser}{dialog}->run();
+    $gui{d}{LogFileChooser}{dialog}->hide();
+    my $filename = $gui{d}{LogFileChooser}{dialog}->get_filename();
 
     if($response eq 'ok' and $filename){
         if (open(my $msg_log_fh, '>', $filename)) {
-            my $iter = $gui{liststoreMsgLog}->get_iter_first();
+            my $iter = $gui{d}{Main}{lstoreMsgLog}->get_iter_first();
 
-            while (defined($iter) and $gui{liststoreMsgLog}->iter_is_valid($iter)) {
-                print $msg_log_fh $gui{liststoreMsgLog}->get($iter, 0) . "\n";
-                $gui{liststoreMsgLog}->iter_next($iter);
+            while (defined($iter) and $gui{d}{Main}{lstoreMsgLog}->iter_is_valid($iter)) {
+                print $msg_log_fh $gui{d}{Main}{lstoreMsgLog}->get($iter, 0) . "\n";
+                $gui{d}{Main}{lstoreMsgLog}->iter_next($iter);
             }
 
             close($msg_log_fh);
@@ -356,13 +366,13 @@ sub show_dialog_exportappl {
     }
 
     do {
-        my $response = $gui{d}{ExportAppl}->run();
+        my $response = $gui{d}{ExportAppl}{dialog}->run();
 
         if ($response eq 'ok') {
             if (!$gui{d}{ExportAppl}{entryFile}->get_text()) { &show_err_msg('invalidfile'); }
             elsif (!$gui{d}{ExportAppl}{entryName}->get_text()) { &show_err_msg('invalidname'); }
             else {
-                $gui{d}{ExportAppl}->hide;
+                $gui{d}{ExportAppl}{dialog}->hide;
                 my $location = $gui{d}{ExportAppl}{entryFile}->get_text() . &getsel_combo($gui{d}{ExportAppl}{cboxFormat}, 2);
                 my $IAppliance = IVirtualBox_createAppliance($gui{websn});
                 foreach my $key (keys(%used_key_ids)) { IAppliance_addPasswords($IAppliance, $key, $used_key_ids{$key}); }
@@ -388,9 +398,9 @@ sub show_dialog_exportappl {
                 &addrow_msg_log("Exported $$gref{Name} as an appliance to $location");
             }
         }
-        else { $gui{d}{ExportAppl}->hide; }
+        else { $gui{d}{ExportAppl}{dialog}->hide; }
 
-    } until (!$gui{d}{ExportAppl}->get_visible());
+    } until (!$gui{d}{ExportAppl}{dialog}->get_visible());
 }
 
 sub show_dialog_snap_details {
@@ -399,8 +409,8 @@ sub show_dialog_snap_details {
     if ($$snapref{ISnapshot}) { # This is needed in case a user double clicks on "Current State" which is not a real snapshot
         $gui{d}{Snapshot}{Name}->set_text(ISnapshot_getName($$snapref{ISnapshot}));
         $gui{d}{Snapshot}{tbDescription}->set_text(ISnapshot_getDescription($$snapref{ISnapshot}));
-        my $response = $gui{d}{Snapshot}->run;
-        $gui{d}{Snapshot}->hide;
+        my $response = $gui{d}{Snapshot}{dialog}->run;
+        $gui{d}{Snapshot}{dialog}->hide;
 
         if ($response eq 'ok') {
             my ($iter_s, $iter_e) = ($gui{d}{Snapshot}{tbDescription}->get_start_iter(), $gui{d}{Snapshot}{tbDescription}->get_end_iter());
@@ -414,8 +424,8 @@ sub show_dialog_snap_details {
 sub show_dialog_snapshot {
     $gui{d}{Snapshot}{Name}->set_text('Snapshot');
     $gui{d}{Snapshot}{tbDescription}->set_text('');
-    my $response = $gui{d}{Snapshot}->run();
-    $gui{d}{Snapshot}->hide();
+    my $response = $gui{d}{Snapshot}{dialog}->run();
+    $gui{d}{Snapshot}{dialog}->hide();
 
     if ($response eq 'ok') {
         my ($iter_s, $iter_e) = ($gui{d}{Snapshot}{tbDescription}->get_start_iter(), $gui{d}{Snapshot}{tbDescription}->get_end_iter());
@@ -595,8 +605,9 @@ sub start_guest {
 # Removes a guest, optionally deleting associated files
 sub remove_guest {
     my $gref = &getsel_list_guest();
-    my $response = $gui{d}{RemoveGuest}->run();
-    $gui{d}{RemoveGuest}->hide;
+    $gui{d}{RemoveGuest}{dialog}->show_all();
+    my $response = $gui{d}{RemoveGuest}{dialog}->run();
+    $gui{d}{RemoveGuest}{dialog}->hide;
 
     if ($response eq '1') { # Remove Only
         IMachine_unregister($$gref{IMachine}, 'DetachAllReturnNone');
@@ -734,13 +745,13 @@ sub show_rmb_menu {
         # This code is needed because if the user just presses the RMB, then GTK has not updated the
         # location of the cursor until AFTER this routine is complete meaning we will be referencing the
         # wrong VM. We need to force a cursor update first.
-        my ($path, $col) = $gui{treeviewGuest}->get_path_at_pos(int($event->x), int($event->y));
+        my ($path, $col) = $gui{d}{Main}{treeviewGuest}->get_path_at_pos(int($event->x), int($event->y));
         if ($path) {
-            $gui{treeviewGuest}->grab_focus();
-            $gui{treeviewGuest}->set_cursor($path, undef, 0);
+            $gui{d}{Main}{treeviewGuest}->grab_focus();
+            $gui{d}{Main}{treeviewGuest}->set_cursor($path, undef, 0);
         }
 
-        $gui{menuDevices}->popup(undef, undef, undef, undef, 0, $event->time);
+        $gui{menu}{Devices}->popup(undef, undef, undef, undef, 0, $event->time);
         return 1;
     }
 
@@ -751,12 +762,12 @@ sub show_rmb_menu {
 sub fill_menu_optical {
     my $vhost = &vhost();
     my $menu = &gui_new_menu();
-    $gui{miDVD}->set_submenu($menu);
+    $gui{mi}{DVD}->set_submenu($menu);
     my $itema = &gui_new_menu_item_no_mnemonic('Add Optical Disc Image', 'cd_add_16px.png', $menu);
     $itema->signal_connect('activate' => \&show_remote_filechooser, {title => 'Choose Disc Image', entrywidget => '', mode => 'file', filter => '^.*\.iso$', callback => \&devices_menu_add_optical_disc});
     my $itemb = &gui_new_menu_item_no_mnemonic('Eject Optical Disc', 'cd_clear_16px.png', $menu);
     $itemb->signal_connect('activate' => \&insert_removable_disk_first_drive, {IMedium => '', type => 'DVD'});
-    $menu->append(&gui_new_menu_sep());
+    $menu->append(Gtk3::SeparatorMenuItem->new());
 
     if ($$vhost{dvd}) {
         my $added;
@@ -767,7 +778,7 @@ sub fill_menu_optical {
             $item->signal_connect('activate' => \&insert_removable_disk_first_drive, {IMedium => $pdvd, type => 'DVD'});
         }
 
-        $menu->append(&gui_new_menu_sep()) if ($added); # Only add separator if a host drive was added
+        $menu->append(Gtk3::SeparatorMenuItem->new()) if ($added); # Only add separator if a host drive was added
     }
 
     my $IMediumRef = &get_all_media('DVD');
@@ -786,7 +797,7 @@ sub fill_menu_usb {
 
     if ($$sref{Lock} eq 'Shared') {
         my $usbmenu =  &gui_new_menu();
-        $gui{miUSB}->set_submenu($usbmenu);
+        $gui{mi}{USB}->set_submenu($usbmenu);
         my @IHostUSBDevices = IHost_getUSBDevices(IVirtualBox_getHost($gui{websn}));
         my @USBDevices = IConsole_getUSBDevices(ISession_getConsole($$sref{ISession}));
 
@@ -814,7 +825,7 @@ sub fill_menu_cpu {
 
     if ($$sref{Lock} eq 'Shared') {
         my $cpumenu = &gui_new_menu();
-        $gui{miHotPlugCPU}->set_submenu($cpumenu);
+        $gui{mi}{HotPlugCPU}->set_submenu($cpumenu);
         my $cpucount = IMachine_getCPUCount($$sref{IMachine});
 
         # CPU 0 is special - it can never be detached.
@@ -891,7 +902,7 @@ sub fill_menu_floppy {
     $itemb->signal_connect('activate' => \&show_dialog_create_floppy, {IMachine => $$gref{IMachine}, filename => &rcatfile($$vhost{machinedir}, 'Floppy-' . int(rand(999999))), callback => \&insert_removable_disk_first_drive});
     my $itemc = &gui_new_menu_item_no_mnemonic('Eject Floppy Disk', 'fd_clear_16px.png', $menu);
     $itemc->signal_connect('activate' => \&insert_removable_disk_first_drive, {IMedium => '', type => 'Floppy'});
-    $menu->append(&gui_new_menu_sep());
+    $menu->append(Gtk3::SeparatorMenuItem->new());
 
     if ($$vhost{floppy}) {
         my $added;
@@ -902,7 +913,7 @@ sub fill_menu_floppy {
             $item->signal_connect('activate' => \&insert_removable_disk_first_drive, {IMedium => $pfloppy, type => 'Floppy'});
         }
 
-        $menu->append(&gui_new_menu_sep()) if ($added); # Only add separator if a host drive was added
+        $menu->append(Gtk3::SeparatorMenuItem->new()) if ($added); # Only add separator if a host drive was added
     }
 
     my $IMediumRef = &get_all_media('Floppy');
@@ -912,7 +923,7 @@ sub fill_menu_floppy {
         $item->signal_connect('activate' => \&insert_removable_disk_first_drive, {IMedium => $_, type => 'Floppy'});
     }
 
-    $gui{miFloppy}->set_submenu($menu);
+    $gui{mi}{Floppy}->set_submenu($menu);
 }
 
 # Called from the devices menu
@@ -940,7 +951,7 @@ sub insert_removable_disk_first_drive {
     foreach my $attach (@IMediumAttachment) {
         next if ($$attach{type} ne $$medium{type});
         IMachine_mountMedium($$sref{IMachine}, $$attach{controller}, $$attach{port}, $$attach{device}, $$medium{IMedium}, 0);
-        &onsel_list_guest() if ($gui{treeviewGuest}->get_selection->get_selected());
+        &onsel_list_guest() if ($gui{d}{Main}{treeviewGuest}->get_selection->get_selected());
         $found = 1;
         &addrow_msg_log("Changed $$medium{type} medium for $$gref{Name}");
         last;
@@ -1009,7 +1020,7 @@ sub send_video_hint {
     my $gref = &getsel_list_guest();
     my $sref = &get_session($$gref{IMachine});
 
-    if ($widget eq $gui{miSetVideoCustom}) { $res = &show_dialog_videohint(); }
+    if ($widget eq $gui{mi}{SetVideoCustom}) { $res = &show_dialog_videohint(); }
 
     # This checks if the custom res window got cancels as the resolution will be 0
     if ($$res[0] > 0) {
@@ -1101,51 +1112,51 @@ sub imedium_has_property {
 # Set sensitivity based on connection state
 sub sens_connect {
     my ($state) = @_;
-    $gui{miNew}->set_sensitive($state);
-    $gui{miAdd}->set_sensitive($state);
-    $gui{miImportAppl}->set_sensitive($state);
-    $gui{miVMM}->set_sensitive($state);
-    $gui{miHostNetMan}->set_sensitive($state);
-    $gui{miServerInfo}->set_sensitive($state);
-    $gui{miVBPrefs}->set_sensitive($state);
-    $gui{toolbuttonNew}->set_sensitive($state);
-    $gui{toolbuttonRefresh}->set_sensitive($state);
-    $gui{progressbarMem}->show();
+    $gui{mi}{New}->set_sensitive($state);
+    $gui{mi}{Add}->set_sensitive($state);
+    $gui{mi}{ImportAppl}->set_sensitive($state);
+    $gui{mi}{VMM}->set_sensitive($state);
+    $gui{mi}{HostNetMan}->set_sensitive($state);
+    $gui{mi}{ServerInfo}->set_sensitive($state);
+    $gui{mi}{VBPrefs}->set_sensitive($state);
+    $gui{d}{Main}{buttonNew}->set_sensitive($state);
+    $gui{d}{Main}{buttonRefresh}->set_sensitive($state);
+    $gui{d}{Main}{barMem}->show();
 }
 
 # Sets the sensitivity when no guest is selected
 sub sens_unselected {
-    $gui{miExportAppl}->set_sensitive(0);
-    $gui{miAction}->set_sensitive(0);
-    $gui{miStart}->set_sensitive(0);
-    $gui{miStop}->set_sensitive(0);
-    $gui{miPause}->set_sensitive(0);
-    $gui{miResume}->set_sensitive(0);
-    $gui{miSettings}->set_sensitive(0);
-    $gui{miClone}->set_sensitive(0);
-    $gui{miSetGroup}->set_sensitive(0);
-    $gui{miUngroup}->set_sensitive(0);
-    $gui{miDiscard}->set_sensitive(0);
-    $gui{miReset}->set_sensitive(0);
-    $gui{miRemove}->set_sensitive(0);
-    $gui{miKeyboard}->set_sensitive(0);
-    $gui{miDisplay}->set_sensitive(0);
-    $gui{miHotPlugCPU}->set_sensitive(0);
-    $gui{miDVD}->set_sensitive(0);
-    $gui{miFloppy}->set_sensitive(0);
-    $gui{miUSB}->set_sensitive(0);
-    $gui{miScreenshot}->set_sensitive(0);
-    $gui{miLogs}->set_sensitive(0);
-    $gui{toolbuttonStart}->set_sensitive(0);
-    $gui{toolbuttonStop}->set_sensitive(0);
-    $gui{toolbuttonSettings}->set_sensitive(0);
-    $gui{toolbuttonRemoteDisplay}->set_sensitive(0);
-    $gui{toolbuttonCAD}->set_sensitive(0);
-    $gui{toolbuttonDiscard}->set_sensitive(0);
-    $gui{toolbuttonReset}->set_sensitive(0);
-    $gui{buttonRefreshSnapshot}->set_sensitive(0);
-    $gui{buttonCloneSnapshot}->set_sensitive(0);
-    $gui{buttonTakeSnapshot}->set_sensitive(0);
+    $gui{mi}{ExportAppl}->set_sensitive(0);
+    $gui{mi}{Action}->set_sensitive(0);
+    $gui{mi}{Start}->set_sensitive(0);
+    $gui{mi}{Stop}->set_sensitive(0);
+    $gui{mi}{Pause}->set_sensitive(0);
+    $gui{mi}{Resume}->set_sensitive(0);
+    $gui{mi}{Settings}->set_sensitive(0);
+    $gui{mi}{Clone}->set_sensitive(0);
+    $gui{mi}{SetGroup}->set_sensitive(0);
+    $gui{mi}{Ungroup}->set_sensitive(0);
+    $gui{mi}{Discard}->set_sensitive(0);
+    $gui{mi}{Reset}->set_sensitive(0);
+    $gui{mi}{Remove}->set_sensitive(0);
+    $gui{mi}{Keyboard}->set_sensitive(0);
+    $gui{mi}{Display}->set_sensitive(0);
+    $gui{mi}{HotPlugCPU}->set_sensitive(0);
+    $gui{mi}{DVD}->set_sensitive(0);
+    $gui{mi}{Floppy}->set_sensitive(0);
+    $gui{mi}{USB}->set_sensitive(0);
+    $gui{mi}{Screenshot}->set_sensitive(0);
+    $gui{mi}{Logs}->set_sensitive(0);
+    $gui{d}{Main}{buttonStart}->set_sensitive(0);
+    $gui{d}{Main}{buttonStop}->set_sensitive(0);
+    $gui{d}{Main}{buttonSettings}->set_sensitive(0);
+    $gui{d}{Main}{buttonDisplay}->set_sensitive(0);
+    $gui{d}{Main}{buttonCAD}->set_sensitive(0);
+    $gui{d}{Main}{buttonDiscard}->set_sensitive(0);
+    $gui{d}{Main}{buttonReset}->set_sensitive(0);
+    $gui{d}{Main}{buttonRefreshSnap}->set_sensitive(0);
+    $gui{d}{Main}{buttonCloneSnap}->set_sensitive(0);
+    $gui{d}{Main}{buttonTakeSnap}->set_sensitive(0);
 }
 
 # Resets the guest icon back to the default
@@ -1159,11 +1170,11 @@ sub reset_icon {
 sub screenshot {
     my $gref = &getsel_list_guest();
     my $sref = &get_session($$gref{IMachine});
-    $gui{d}{ScreenShotFileChooser}->set_current_name("$$gref{Name}_screenshot.png");
-    $gui{d}{ScreenShotFileChooser}->set_current_folder($ENV{HOME}) if ($ENV{HOME});
-    my $response = $gui{d}{ScreenShotFileChooser}->run();
-    $gui{d}{ScreenShotFileChooser}->hide();
-    my $filename = $gui{d}{ScreenShotFileChooser}->get_filename();
+    $gui{d}{ScreenShotFileChooser}{dialog}->set_current_name("$$gref{Name}_screenshot.png");
+    $gui{d}{ScreenShotFileChooser}{dialog}->set_current_folder($ENV{HOME}) if ($ENV{HOME});
+    my $response = $gui{d}{ScreenShotFileChooser}{dialog}->run();
+    $gui{d}{ScreenShotFileChooser}{dialog}->hide();
+    my $filename = $gui{d}{ScreenShotFileChooser}{dialog}->get_filename();
 
     if ($response eq 'ok' and $filename) {
         if ($$sref{Lock} eq 'Shared') {
@@ -1216,13 +1227,13 @@ sub screenshot_to_icon {
 }
 
 sub group_list_expand {
-    $gui{treeviewGuest}->expand_all();
+    $gui{d}{Main}{treeviewGuest}->expand_all();
     $prefs{GUESTLISTEXPAND}=1;
     &rbprefs_save();
 }
 
 sub group_list_collapse {
-    $gui{treeviewGuest}->collapse_all();
+    $gui{d}{Main}{treeviewGuest}->collapse_all();
     $prefs{GUESTLISTEXPAND}=0;
     &rbprefs_save();
 }
@@ -1233,17 +1244,18 @@ sub show_dialog_importappl {
     $gui{d}{ImportAppl}{entryAppl}->set_text(&rcatfile($$vhost{machinedir}, 'appliance.ova'));
 
     do {
-        my $response = $gui{d}{ImportAppl}->run();
+        $gui{d}{ImportAppl}{dialog}->show_all();
+        my $response = $gui{d}{ImportAppl}{dialog}->run();
 
         if ($response eq 'ok') {
             my @importopts;
-            push (@importopts, 'ImportToVDI') if ($gui{checkbuttonImportApplToVDI}->get_active() == 1);
+            push (@importopts, 'ImportToVDI') if ($gui{d}{ImportAppl}{checkConvert}->get_active() == 1);
             push (@importopts, 'KeepAllMACs') if ($gui{d}{ImportAppl}{cboxMAC}->get_active() == 0);
             push (@importopts, 'KeepNATMACs') if ($gui{d}{ImportAppl}{cboxMAC}->get_active() == 1);
 
             if (!$gui{d}{ImportAppl}{entryAppl}->get_text()) { &show_err_msg('invalidfile'); }
             else {
-                $gui{d}{ImportAppl}->hide;
+                $gui{d}{ImportAppl}{dialog}->hide();
                 my $appliancefile = $gui{d}{ImportAppl}{entryAppl}->get_text();
                 &addrow_msg_log("Importing appliance from $appliancefile");
                 my $IAppliance = IVirtualBox_createAppliance($gui{websn});
@@ -1271,9 +1283,9 @@ sub show_dialog_importappl {
                 else { &show_err_msg('applimport', "\nAppliance: $appliancefile"); }
             }
         }
-        else { $gui{d}{ImportAppl}->hide; }
+        else { $gui{d}{ImportAppl}{dialog}->hide; }
 
-    } until (!$gui{d}{ImportAppl}->get_visible());
+    } until (!$gui{d}{ImportAppl}{dialog}->get_visible());
 }
 
 # Displays the dialog for entering a decryption password
@@ -1282,8 +1294,9 @@ sub show_dialog_decpasswd {
     my $passwd;
     $gui{d}{DecPassword}{labelKeyID}->set_text($keyid);
     $gui{d}{DecPassword}{labelDisk}->set_text(IMedium_getName($IMedium));
-    my $response = $gui{d}{DecPassword}->run;
-    $gui{d}{DecPassword}->hide;
+    $gui{d}{DecPassword}{dialog}->show_all();
+    my $response = $gui{d}{DecPassword}{dialog}->run();
+    $gui{d}{DecPassword}{dialog}->hide();
     if ($response eq 'ok') { $passwd = $gui{d}{DecPassword}{entryPass}->get_text(); }
     return $passwd;
 }
@@ -1296,8 +1309,9 @@ sub show_dialog_group {
     if ($$sref{Lock} ne 'None') {
         my ($group) = IMachine_getGroups($$sref{IMachine}, ('/')); # Only interested in first group entry
         $gui{d}{SetGroup}{entryGroup}->set_text($group);
-        my $response = $gui{d}{SetGroup}->run();
-        $gui{d}{SetGroup}->hide;
+        $gui{d}{SetGroup}{dialog}->show_all();
+        my $response = $gui{d}{SetGroup}{dialog}->run();
+        $gui{d}{SetGroup}{dialog}->hide();
 
         if ($response eq 'ok') {
             $group = $gui{d}{SetGroup}{entryGroup}->get_text();
@@ -1334,8 +1348,8 @@ sub update_server_membar {
         my $vhost = &vhost();
         my $memavail = IHost_getMemoryAvailable($$vhost{IHost});
         my $memused = ($$vhost{memsize} - $memavail);
-        $gui{progressbarMem}->set_text("Server Memory ($$vhost{memsize} MB): $memused MB Used / $memavail MB Free");
-        $gui{progressbarMem}->set_fraction(($memused / $$vhost{memsize}));
+        $gui{d}{Main}{barMem}->set_text("Server Memory ($$vhost{memsize} MB): $memused MB Used / $memavail MB Free");
+        $gui{d}{Main}{barMem}->set_fraction(($memused / $$vhost{memsize}));
     }
 
     return 1; # Return 1 to stop the timer from being removed
@@ -1343,8 +1357,8 @@ sub update_server_membar {
 
 # Display extended details when a guest is selected
 sub extended_details {
-    $prefs{EXTENDEDDETAILS} = $gui{checkbuttonShowDetails}->get_active();
-    &onsel_list_guest() if ($gui{treeviewGuest}->get_selection->get_selected());
+    $prefs{EXTENDEDDETAILS} = $gui{d}{Main}{checkbuttonDetails}->get_active();
+    &onsel_list_guest() if ($gui{d}{Main}{treeviewGuest}->get_selection->get_selected());
 }
 
 sub set_connection_prof_inactive {
