@@ -60,13 +60,13 @@ sub show_dialog_new_guest {
     &fill_list_new_guest_dvd();
 
     do {
-        my $response = $gui{d}{New}->run;
+        my $response = $gui{d}{New}{dialog}->run();
 
         if ($response eq 'ok') {
             # Other entries do not require validation
             if (!$gui{d}{New}{entryName}->get_text()) { &show_err_msg('invalidname'); }
             else {
-                $gui{d}{New}->hide();
+                $gui{d}{New}{dialog}->hide();
                 my $name = $gui{d}{New}{entryName}->get_text();
                 my $IMachine = IVirtualBox_createMachine($gui{websn}, '', $name, &getsel_combo($gui{d}{New}{cboxVersion}, 2), '', &getsel_combo($gui{d}{New}{cboxVersion}, 1), 'UUID=' . &generate_uuid(), '');
 
@@ -147,9 +147,9 @@ sub show_dialog_new_guest {
                 else { &show_err_msg('createguest', " ($name)"); }
             }
         }
-        else { $gui{d}{New}->hide; }
+        else { $gui{d}{New}{dialog}->hide(); }
 
-    } until (!$gui{d}{New}->get_visible());
+    } until (!$gui{d}{New}{dialog}->get_visible());
 }
 
 # Shows the dialog for creating a new clone
@@ -158,14 +158,14 @@ sub show_dialogClone {
     $gui{d}{Clone}{entryName}->set_text($$gref{Name} . '-Clone-' . int(rand(999999)));
 
     do {
-        $gui{d}{Clone}->show_all;
-        my $response = $gui{d}{Clone}->run();
+        $gui{d}{Clone}{dialog}->show_all;
+        my $response = $gui{d}{Clone}{dialog}->run();
 
         if ($response eq 'ok') {
             # No validation needed for other entries
             if (!$gui{d}{Clone}{entryName}->get_text()) { &show_err_msg('invalidname'); }
             else {
-                $gui{d}{Clone}->hide;
+                $gui{d}{Clone}{dialog}->hide;
 
                 my %newclone = (name    => $gui{d}{Clone}{entryName}->get_text(),
                                 mode    => 'MachineState',
@@ -188,9 +188,9 @@ sub show_dialogClone {
                 &fill_list_guest();
             }
         }
-        else { $gui{d}{Clone}->hide; }
+        else { $gui{d}{Clone}{dialog}->hide; }
 
-    } until (!$gui{d}{Clone}->get_visible());
+    } until (!$gui{d}{Clone}{dialog}->get_visible());
 }
 
 # Determines the next free port number and device number on a controller. If
