@@ -37,11 +37,6 @@ sub rbprefs_get {
     $gui{PROFILESFILE} = "$gui{PREFSDIR}/remotebox-profiles.conf";
     $gui{THUMBDIR} = "$gui{PREFSDIR}/remoteboxthumbs";
 
-    # See if we can make some more useful defaults for OSs which don't have xfreerdp
-    if ($^O =~ m/netbsd/i) { $prefs{RDPCLIENT} = 'rdesktop -g %Xx%Y -r sound:local -r clipboard:PRIMARYCLIPBOARD -T "%n - RemoteBox" %h:%p'; }
-    elsif ($^O =~ m/solaris/i) { $prefs{RDPCLIENT} = 'rdesktop -g %Xx%Y -r sound:local -r clipboard:PRIMARYCLIPBOARD -T "%n - RemoteBox" %h:%p'; }
-    elsif ($^O =~ m/MSWin/) { $prefs{RDPCLIENT} = 'mstsc /w:%X /h:%Y /v:%h:%p'; }
-
     if (open(PREFS, '<', $gui{CONFIGFILE})) {
         my @contents = <PREFS>;
         chomp(@contents);
@@ -54,7 +49,7 @@ sub rbprefs_get {
     }
     else { $prefs{URL}{qq[http://localhost:18083]} = 'URL'; } #Add a default URL
 
-    $gui{checkbuttonShowDetails}->set_active($prefs{EXTENDEDDETAILS});
+    $gui{d}{Main}{checkbuttonDetails}->set_active($prefs{EXTENDEDDETAILS});
 
     # Load in the connection profiles
     if (open(PROFILES, '<', $gui{PROFILESFILE})) {
@@ -120,13 +115,40 @@ sub rbprofiles_save {
 
 # Save RemoteBox's window position for restoration later
 sub save_window_pos {
-    my ($winname) = @_;
-    my ($w, $h) = $gui{$winname}->get_size();
-    my ($x, $y) = $gui{$winname}->get_position();
-    $prefs{"WINPOS_$winname"} = "$w:$h:$x:$y";
+    if (defined($ENV{GDK_BACKEND}) and $ENV{GDK_BACKEND} =~ m/broadway/i) {
+        # There's probably a nicer way to check for this, but...
+        # We don't save the window position because the browser settings will be very
+        # different to the desktop settings.
+    }
+    else {
+        my ($win) = @_;
+        my ($w, $h) = $win->get_size();
+        my ($x, $y) = $win->get_position();
+        $prefs{"WINPOS_windowMain"} = "$w:$h:$x:$y";
+    }
+
     &rbprefs_save();
 }
 
+# Restore RemoteBox's window position to the last save position
+sub restore_window_pos {
+    my ($win) = @_;
+
+    if (defined($ENV{GDK_BACKEND}) and $ENV{GDK_BACKEND} =~ m/broadway/i) {
+        # There's probably a nicer way to check for this, but...
+        # We don't restore the window position because the browser settings will be very
+        # different to the desktop settings.
+        $win->maximize();
+    }
+    else {
+        if ($prefs{"WINPOS_windowMain"}) {
+            my ($w, $h, $x, $y) = split ':', $prefs{"WINPOS_windowMain"};
+            $win->move($x, $y);
+            $win->resize($w, $h);
+        }
+    }
+}
+
 sub show_dialog_editnat {
     my $natref = &getsel_list_vbprefsnat();
     $gui{d}{NAT}{entryName}->set_text($$natref{Name});
@@ -138,15 +160,15 @@ sub show_dialog_editnat {
     &fill_list_pf6($$natref{INATNetwork});
 
     do {
-        $gui{d}{NAT}->show_all;
-        my $response = $gui{d}{NAT}->run();
+        $gui{d}{NAT}{dialog}->show_all;
+        my $response = $gui{d}{NAT}{dialog}->run();
 
         if ($response eq 'ok') {
             # Other entries do not require validation
             if (!$gui{d}{NAT}{entryName}->get_text()) { &show_err_msg('invalidname'); }
             elsif (!&valid_cidr($gui{d}{NAT}{entryCIDR}->get_text())) { &show_err_msg('invalidipv4cidr', '(Network CIDR)'); }
             else {
-                $gui{d}{NAT}->hide;
+                $gui{d}{NAT}{dialog}->hide;
                 INATNetwork_setNetworkName($$natref{INATNetwork}, $gui{d}{NAT}{entryName}->get_text());
                 INATNetwork_setNetwork($$natref{INATNetwork}, $gui{d}{NAT}{entryCIDR}->get_text());
                 INATNetwork_setNeedDhcpServer($$natref{INATNetwork}, int($gui{d}{NAT}{checkDHCP}->get_active()));
@@ -155,9 +177,9 @@ sub show_dialog_editnat {
                 &fill_list_vbprefsnat();
             }
         }
-        else { $gui{d}{NAT}->hide; }
+        else { $gui{d}{NAT}{dialog}->hide; }
 
-    } until (!$gui{d}{NAT}->get_visible());
+    } until (!$gui{d}{NAT}{dialog}->get_visible());
 }
 
 # Show dialog for adding an IPv4 port forwarding rule
@@ -178,8 +200,8 @@ sub show_dialog_pf4 {
     else { $gui{d}{PFRule4}{entryName}->set_text('Rule ' . int(rand(999999))); }
 
     do {
-        $gui{d}{PFRule4}->show_all;
-        my $response = $gui{d}{PFRule4}->run();
+        $gui{d}{PFRule4}{dialog}->show_all;
+        my $response = $gui{d}{PFRule4}{dialog}->run();
 
         if ($response eq 'ok') {
             # No validation needed for other entries
@@ -187,7 +209,7 @@ sub show_dialog_pf4 {
             elsif (!valid_ipv4($gui{d}{PFRule4}{entryHostIP}->get_text())) { &show_err_msg('invalidipv4address', '(Host IP)'); }
             elsif (!valid_ipv4($gui{d}{PFRule4}{entryGuestIP}->get_text())) { &show_err_msg('invalidipv4address', '(Guest IP)'); }
             else {
-                $gui{d}{PFRule4}->hide;
+                $gui{d}{PFRule4}{dialog}->hide;
                 my $natref = &getsel_list_vbprefsnat();
                 # We can't actually edit an existing rule, so it's deleted and recreated.
                 INATNetwork_removePortForwardRule($$natref{INATNetwork}, 0, $oldname) if ($mode eq 'EDIT');
@@ -201,9 +223,9 @@ sub show_dialog_pf4 {
                 &fill_list_pf4($$natref{INATNetwork});
             }
         }
-        else { $gui{d}{PFRule4}->hide; }
+        else { $gui{d}{PFRule4}{dialog}->hide; }
 
-    } until (!$gui{d}{PFRule4}->get_visible());
+    } until (!$gui{d}{PFRule4}{dialog}->get_visible());
 }
 
 # Show dialog for adding an IPv6 port forwarding rule
@@ -224,16 +246,16 @@ sub show_dialog_pf6 {
     else { $gui{d}{PFRule6}{entryName}->set_text('Rule ' . int(rand(999999))); }
 
     do {
-        $gui{d}{PFRule6}->show_all;
-        my $response = $gui{d}{PFRule6}->run();
+        $gui{d}{PFRule6}{dialog}->show_all;
+        my $response = $gui{d}{PFRule6}{dialog}->run();
 
         if ($response eq 'ok') {
             # No validation needed for other entries
             if (!$gui{d}{PFRule6}{entryName}->get_text()) { &show_err_msg('invalidname', '(Portforwarding rule name)'); }
             elsif (!valid_ipv6($gui{d}{PFRule6}{entryHostIP}->get_text())) { &show_err_msg('invalidipv6address', '(Host IP)'); }
-            elsif (!valid_ipv6($gui{d}{PFRule6}{entryGuestIP}->get_text())) { &show_err_msg('invalidip64address', '(Guest IP)'); }
+            elsif (!valid_ipv6($gui{d}{PFRule6}{entryGuestIP}->get_text())) { &show_err_msg('invalidipv6address', '(Guest IP)'); }
             else {
-                $gui{d}{PFRule6}->hide;
+                $gui{d}{PFRule6}{dialog}->hide;
                 my $natref = &getsel_list_vbprefsnat();
                 # We can't actually edit an existing rule, so it's deleted and recreated.
                 INATNetwork_removePortForwardRule($$natref{INATNetwork}, 1, $oldname) if ($mode eq 'EDIT');
@@ -247,9 +269,9 @@ sub show_dialog_pf6 {
                 &fill_list_pf6($$natref{INATNetwork});
             }
         }
-        else { $gui{d}{PFRule6}->hide; }
+        else { $gui{d}{PFRule6}{dialog}->hide; }
 
-    } until (!$gui{d}{PFRule6}->get_visible());
+    } until (!$gui{d}{PFRule6}{dialog}->get_visible());
 }
 
 # Removes an IPv4 port forwarding rule to the selected NAT Network
@@ -285,8 +307,9 @@ sub show_dialog_prefs {
     elsif ($prefs{STOPTYPE} eq 'STATE')  { $gui{d}{Prefs}{cboxStop}->set_active(2); }
     else { $gui{d}{Prefs}{cboxStop}->set_active(0); }
 
-    my $response = $gui{d}{Prefs}->run;
-    $gui{d}{Prefs}->hide;
+    $gui{d}{Prefs}{dialog}->show_all();
+    my $response = $gui{d}{Prefs}{dialog}->run();
+    $gui{d}{Prefs}{dialog}->hide();
 
     if ($response eq 'ok') {
         $prefs{RDPCLIENT} = $gui{d}{Prefs}{entryRDP}->get_text();
@@ -310,9 +333,9 @@ sub show_dialog_vbprefs {
     $gui{d}{VBPrefs}{entryDatabaseFolder}->set_text($$vhost{autostartdb});
     $gui{d}{VBPrefs}{entryVRDPLib}->set_text($$vhost{vrdelib});
     $gui{d}{VBPrefs}{checkExclusive}->set_active(&bl($$vhost{hwexclusive}));
-    $gui{d}{VBPrefs}->show_all;
-    my $response = $gui{d}{VBPrefs}->run();
-    $gui{d}{VBPrefs}->hide();
+    $gui{d}{VBPrefs}{dialog}->show_all();
+    my $response = $gui{d}{VBPrefs}{dialog}->run();
+    $gui{d}{VBPrefs}{dialog}->hide();
 
     if ($response eq 'ok') {
         my $machinedir = $gui{d}{VBPrefs}{entryMachineFolder}->get_text();
@@ -329,18 +352,28 @@ sub show_dialog_vbprefs {
     }
 }
 
+# Shows the RDPVNCInfo dialog
+sub show_dialog_rdpvncinfo {
+    &fill_list_rdpvncinfo();
+    $gui{d}{RDPVNCInfo}{dialog}->show_all();
+    $gui{d}{RDPVNCInfo}{dialog}->run();
+    $gui{d}{RDPVNCInfo}{dialog}->hide();
+}
+
 # Shows the Host Network Manager dialog
 sub show_dialog_hostnetman {
     &fill_list_vbprefshon();
     &fill_list_vbprefsnat();
-    $gui{d}{HostNetMan}->run();
-    $gui{d}{HostNetMan}->hide();
+    $gui{d}{HostNetMan}{dialog}->show_all();
+    $gui{d}{HostNetMan}{dialog}->run();
+    $gui{d}{HostNetMan}{dialog}->hide();
 }
 
 # Shows the dialog for managing connection profiles
 sub show_dialog_profiles {
-    $gui{d}{Profile}->run;
-    $gui{d}{Profile}->hide;
+    $gui{d}{Profile}{dialog}->show_all();
+    $gui{d}{Profile}{dialog}->run();
+    $gui{d}{Profile}{dialog}->hide();
     &rbprofiles_save();
 }
 
@@ -357,47 +390,80 @@ sub show_dialog_edithon {
         }
     }
 
-    # If not DHCP server, then create one.
-    $IDHCPServer = IVirtualBox_createDHCPServer($gui{websn}, "HostInterfaceNetworking-$$ifref{Name}") if (!$IDHCPServer);
+    $gui{d}{HON}{checkEnableDHCP}->signal_connect('toggled' => \&vbprefs_hon_dhcp_toggle, $IDHCPServer);
     $gui{d}{HON}{entryIPV4Addr}->set_text(IHostNetworkInterface_getIPAddress($$ifref{IHostNetworkInterface}));
     $gui{d}{HON}{entryIPV4Netmask}->set_text(IHostNetworkInterface_getNetworkMask($$ifref{IHostNetworkInterface}));
     $gui{d}{HON}{entryIPV6Addr}->set_text(IHostNetworkInterface_getIPV6Address($$ifref{IHostNetworkInterface}));
     $gui{d}{HON}{entryIPV6Netmask}->set_text(IHostNetworkInterface_getIPV6NetworkMaskPrefixLength($$ifref{IHostNetworkInterface}));
-    $gui{d}{HON}{checkEnableDHCP}->set_active(&bl(IDHCPServer_getEnabled($IDHCPServer)));
-    $gui{d}{HON}{entryUpperBound}->set_sensitive($gui{d}{HON}{checkEnableDHCP}->get_active()); # Ghost/Unghost other widgets based on dhcp enabled
-    $gui{d}{HON}{entryServerAddr}->set_text(IDHCPServer_getIPAddress($IDHCPServer));
-    $gui{d}{HON}{entryServerNetmask}->set_text(IDHCPServer_getNetworkMask($IDHCPServer));
-    $gui{d}{HON}{entryLowerBound}->set_text(IDHCPServer_getLowerIP($IDHCPServer));
-    $gui{d}{HON}{entryUpperBound}->set_text(IDHCPServer_getUpperIP($IDHCPServer));
+    $gui{d}{HON}{gridDHCP}->set_sensitive($gui{d}{HON}{checkEnableDHCP}->get_active());
+
+    if (!$IDHCPServer or !&bl(IDHCPServer_getEnabled($IDHCPServer))) { $gui{d}{HON}{checkEnableDHCP}->set_active(0); }
+    else { $gui{d}{HON}{checkEnableDHCP}->set_active(1); }
 
     do {
-        #$gui{d}{HON}->show_all;
-        my $response = $gui{d}{HON}->run();
+        $gui{d}{HON}{dialog}->show_all();
+        my $response = $gui{d}{HON}{dialog}->run();
 
         if ($response eq 'ok') {
-                # NO VALIDATION ON IPv6 Address or IPv6 Netmask Length
-                if (!valid_ipv4($gui{d}{HON}{entryIPV4Addr}->get_text())) { &show_err_msg('invalidipv4address', '(Adapter IPv4 Address)'); }
-                elsif (!valid_ipv4($gui{d}{HON}{entryIPV4Netmask}->get_text())) { &show_err_msg('invalidipv4netmask', '(Adapter IPv4 Netmask)'); }
-                elsif (!valid_ipv4($gui{d}{HON}{entryServerAddr}->get_text())) { &show_err_msg('invalidipv4address', '(DHCP Server Address)'); }
-                elsif (!valid_ipv4($gui{d}{HON}{entryServerNetmask}->get_text())) { &show_err_msg('invalidipv4netmask', '(DHCP Server Netmask)'); }
-                elsif (!valid_ipv4($gui{d}{HON}{entryLowerBound}->get_text())) { &show_err_msg('invalidipv4address', '(DHCP Server Lower Address Bound)'); }
-                elsif (!valid_ipv4($gui{d}{HON}{entryUpperBound}->get_text())) { &show_err_msg('invalidipv4address', '(DHCP Server Upper Address Bound)'); }
-                else {
-                    $gui{d}{HON}->hide();
-                    IDHCPServer_setEnabled($IDHCPServer, $gui{d}{HON}{checkEnableDHCP}->get_active());
+            # Validate everything BEFORE closing the dialog
+            my $valid = TRUE;
+            my $active = $gui{d}{HON}{checkEnableDHCP}->get_active();
+            my $ipv6addr = $gui{d}{HON}{entryIPV6Addr}->get_text();
+
+            if (!valid_ipv4($gui{d}{HON}{entryIPV4Addr}->get_text())) {
+                $valid = FALSE;
+                &show_err_msg('invalidipv4address', '(Adapter IPv4 Address)');
+            }
+            elsif (!valid_ipv4($gui{d}{HON}{entryIPV4Netmask}->get_text())) {
+                $valid = FALSE;
+                &show_err_msg('invalidipv4netmask', '(Adapter IPv4 Netmask)');
+            }
+            elsif ($ipv6addr and !valid_ipv6($ipv6addr)) {
+                $valid = FALSE;
+                &show_err_msg('invalidipv6address', '(Adapter IPv6 Address)');
+            }
+
+            if ($active) {
+                if (!valid_ipv4($gui{d}{HON}{entryServerAddr}->get_text())) {
+                    $valid = FALSE;
+                    &show_err_msg('invalidipv4address', '(DHCP Server Address)');
+                }
+                elsif (!valid_ipv4($gui{d}{HON}{entryServerNetmask}->get_text())) {
+                    $valid = FALSE;
+                    &show_err_msg('invalidipv4netmask', '(DHCP Server Netmask)');
+                }
+                elsif (!valid_ipv4($gui{d}{HON}{entryLowerBound}->get_text())) {
+                    $valid = FALSE;
+                    &show_err_msg('invalidipv4address', '(DHCP Server Lower Address Bound)');
+                }
+                elsif (!valid_ipv4($gui{d}{HON}{entryUpperBound}->get_text())) {
+                    $valid = FALSE;
+                    &show_err_msg('invalidipv4address', '(DHCP Server Upper Address Bound)');
+                }
+            }
+
+            if ($valid == TRUE) {
+                $gui{d}{HON}{dialog}->hide();
+
+                if ($active) {
+                    # When a HON is created, there's no guarantee a DHCP server is associated with it. So here we create one
+                    # If one doesn't exist,
+                    $IDHCPServer = IVirtualBox_createDHCPServer($gui{websn}, "HostInterfaceNetworking-$$ifref{Name}") if (!$IDHCPServer);
+                    IDHCPServer_setEnabled($IDHCPServer, $active);
                     IDHCPServer_setConfiguration($IDHCPServer, $gui{d}{HON}{entryServerAddr}->get_text(),
                                                                $gui{d}{HON}{entryServerNetmask}->get_text(),
                                                                $gui{d}{HON}{entryLowerBound}->get_text(),
                                                                $gui{d}{HON}{entryUpperBound}->get_text());
+                }
 
-                    IHostNetworkInterface_enableStaticIPConfig($$ifref{IHostNetworkInterface}, $gui{d}{HON}{entryIPV4Addr}->get_text() , $gui{d}{HON}{entryIPV4Netmask}->get_text());
-                    IHostNetworkInterface_enableStaticIPConfigV6($$ifref{IHostNetworkInterface}, $gui{d}{HON}{entryIPV6Addr}->get_text(), $gui{d}{HON}{entryIPV6Netmask}->get_text());
-                    &fill_list_vbprefshon();
+                IHostNetworkInterface_enableStaticIPConfig($$ifref{IHostNetworkInterface}, $gui{d}{HON}{entryIPV4Addr}->get_text() , $gui{d}{HON}{entryIPV4Netmask}->get_text());
+                IHostNetworkInterface_enableStaticIPConfigV6($$ifref{IHostNetworkInterface}, $ipv6addr, $gui{d}{HON}{entryIPV6Netmask}->get_text()) if ($ipv6addr);
+                &fill_list_vbprefshon();
             }
         }
-        else { $gui{d}{HON}->hide(); }
+        else { $gui{d}{HON}{dialog}->hide(); }
 
-    } until (!$gui{d}{HON}->get_visible());
+    } until (!$gui{d}{HON}{dialog}->get_visible());
 }
 
 sub vbprefs_reset {
@@ -468,20 +534,48 @@ sub rbprefs_sslverify {
 }
 
 sub vbprefs_hon_dhcp_toggle {
-    $gui{d}{HON}{entryUpperBound}->set_sensitive($gui{d}{HON}{checkEnableDHCP}->get_active()); # Ghost/Unghost other widgets based on dhcp enabled
+    my ($widget, $IDHCPServer) = @_;
+    my $active = $widget->get_active();
+    $gui{d}{HON}{gridDHCP}->set_sensitive($active); # Ghost/Unghost other widgets based on dhcp enabled
+
+    if ($active) {
+        if (!$IDHCPServer) {
+            # There's no existing DHCP server associated with this network, so pre-fill reasonable details
+            my $ip4 = $gui{d}{HON}{entryIPV4Addr}->get_text();
+            my $nm = $gui{d}{HON}{entryIPV4Netmask}->get_text();
+            $gui{d}{HON}{entryServerNetmask}->set_text($nm);
+            $gui{d}{HON}{entryServerAddr}->set_text(&ip4_add($ip4, 1));
+            $gui{d}{HON}{entryLowerBound}->set_text(&ip4_add($ip4, 2));
+            $gui{d}{HON}{entryUpperBound}->set_text(&ip4_highest($ip4, $nm));
+        }
+        else {
+            # There's an existing DHCP server.
+            $gui{d}{HON}{entryServerAddr}->set_text(IDHCPServer_getIPAddress($IDHCPServer));
+            $gui{d}{HON}{entryServerNetmask}->set_text(IDHCPServer_getNetworkMask($IDHCPServer));
+            $gui{d}{HON}{entryLowerBound}->set_text(IDHCPServer_getLowerIP($IDHCPServer));
+            $gui{d}{HON}{entryUpperBound}->set_text(IDHCPServer_getUpperIP($IDHCPServer));
+        }
+    }
+    else {
+        # Not active so blank the fields
+        $gui{d}{HON}{entryServerAddr}->set_text('');
+        $gui{d}{HON}{entryServerNetmask}->set_text('');
+        $gui{d}{HON}{entryLowerBound}->set_text('');
+        $gui{d}{HON}{entryUpperBound}->set_text('');
+    }
 }
 
 # Shows the preset RDP options for selection
 sub show_rdppreset_menu {
     my ($widget, $event) = @_; #$event->time
-    $gui{menuRDPPreset}->popup(undef, undef, undef, undef, 0, $event->time) if ($event->button == 1);
+    $gui{menu}{RDPPreset}->popup(undef, undef, undef, undef, 0, $event->time) if ($event->button == 1);
     return 0;
 }
 
 # Shows the preset VNC options for selection
 sub show_vncpreset_menu {
     my ($widget, $event) = @_; #$event->time
-    $gui{menuVNCPreset}->popup(undef, undef, undef, undef, 0, $event->time) if ($event->button == 1);
+    $gui{menu}{VNCPreset}->popup(undef, undef, undef, undef, 0, $event->time) if ($event->button == 1);
     return 0;
 }
 
