@@ -13,14 +13,15 @@ sub register_medium {
 
 sub show_dialog_vmm {
     &addrow_msg_log('Retrieving global media information');
-    &busy_window($gui{windowMain}, 0, 'watch');
+    &busy_window($gui{d}{Main}{win}, 0, 'watch');
     &fill_list_vmmhd();
     &fill_list_vmmdvd();
     &fill_list_vmmfloppy();
     &addrow_msg_log('Retrieved global media information');
-    &busy_window($gui{windowMain}, 0);
-    $gui{d}{VMM}->run;
-    $gui{d}{VMM}->hide;
+    &busy_window($gui{d}{Main}{win}, 0);
+    $gui{d}{VMM}{dialog}->show_all();
+    $gui{d}{VMM}{dialog}->run();
+    $gui{d}{VMM}{dialog}->hide();
 }
 
 # Handles GUI changes when user selects a different tab
@@ -107,13 +108,15 @@ sub vmm_release {
     else { &fill_list_vmmfloppy(); }
 }
 
+# Remove Hard Drive
 sub vmm_rem {
     my $page = $gui{d}{VMM}{notebook}->get_current_page();
 
     if ($page == 0) {
         my $hdref = &getsel_list_vmmhd();
-        my $response = $gui{d}{RemoveHD}->run;
-        $gui{d}{RemoveHD}->hide;
+        $gui{d}{RemoveHD}{dialog}->show_all();
+        my $response = $gui{d}{RemoveHD}{dialog}->run();
+        $gui{d}{RemoveHD}{dialog}->hide();
 
         if ($response eq '1') { # Deletes Disk (not cancellable)
             my $MediumState = IMedium_refreshState($$hdref{IMedium});
@@ -247,10 +250,9 @@ sub show_dialog_vmm_move {
     my $vhost = &vhost();
     $gui{d}{MoveMedium}{entrySrc}->set_text($$mediumref{Location});
     $gui{d}{MoveMedium}{entryDst}->set_text(&rcatfile($$vhost{machinedir}, $$mediumref{Name}));
-
-    $gui{d}{MoveMedium}->show_all;
-    my $response = $gui{d}{MoveMedium}->run;
-    $gui{d}{MoveMedium}->hide();
+    $gui{d}{MoveMedium}{dialog}->show_all();
+    my $response = $gui{d}{MoveMedium}{dialog}->run();
+    $gui{d}{MoveMedium}{dialog}->hide();
 
     if ($response eq 'ok') {
         my $IProgress = IMedium_moveTo($$mediumref{IMedium}, $gui{d}{MoveMedium}{entryDst}->get_text());
@@ -272,8 +274,9 @@ sub show_dialog_vmm_modify {
     $gui{d}{ModifyHD}{sbSize}->set_value($hdsizemb);
     $gui{d}{ModifyHD}{entryHD}->set_text($$hdref{Name});
     &combobox_set_active_text($gui{d}{ModifyHD}{cboxType}, $$hdref{Type}, 0);
-    my $response = $gui{d}{ModifyHD}->run;
-    $gui{d}{ModifyHD}->hide;
+    $gui{d}{ModifyHD}{dialog}->show_all();
+    my $response = $gui{d}{ModifyHD}{dialog}->run();
+    $gui{d}{ModifyHD}{dialog}->hide();
 
     if ($response eq 'ok') {
         my $newhdsizemb = $gui{d}{ModifyHD}{sbSize}->get_value_as_int(); # Do any resize first because it may not be possible once the type has changed
@@ -310,8 +313,9 @@ sub show_dialog_vmm_copy_hd {
     $gui{d}{CopyHD}{radioDynamic}->set_active(1);
     $gui{d}{CopyHD}{radioFixed}->set_sensitive(1);
     $gui{d}{CopyHD}{radioSplit}->set_sensitive(0);
-    my $response = $gui{d}{CopyHD}->run;
-    $gui{d}{CopyHD}->hide();
+    $gui{d}{CopyHD}{dialog}->show_all();
+    my $response = $gui{d}{CopyHD}{dialog}->run;
+    $gui{d}{CopyHD}{dialog}->hide();
 
     if ($response eq 'ok') {
         my ($vol, $dir, $file) = &rsplitpath($gui{d}{CopyHD}{entryDest}->get_text());
@@ -339,9 +343,9 @@ sub show_dialog_vmm_copy_floppy {
     $newfloppy =~ m/(.*)\.[^.]+$/; # Strip any extension
     $gui{d}{CopyFloppy}{entryDst}->set_text($1 . '-copy-' . int(rand(999999)));
     $gui{d}{CopyFloppy}{entrySrc}->set_text($$fdref{Location});
-    $gui{d}{CopyFloppy}->show_all;
-    my $response = $gui{d}{CopyFloppy}->run();
-    $gui{d}{CopyFloppy}->hide();
+    $gui{d}{CopyFloppy}{dialog}->show_all();
+    my $response = $gui{d}{CopyFloppy}{dialog}->run();
+    $gui{d}{CopyFloppy}{dialog}->hide();
 
     if ($response eq 'ok') {
         my ($vol, $dir, $file) = &rsplitpath($gui{d}{CopyFloppy}{entryDst}->get_text());
@@ -412,14 +416,14 @@ sub show_dialog_create_floppy {
     $gui{d}{CreateFloppy}{entryImage}->set_text($$data{filename});
 
     do {
-        $gui{d}{CreateFloppy}->show_all;
-        my $response = $gui{d}{CreateFloppy}->run();
+        $gui{d}{CreateFloppy}{dialog}->show_all;
+        my $response = $gui{d}{CreateFloppy}{dialog}->run();
 
         if ($response eq 'ok') {
             # No validation needed on other entries
             if (!$gui{d}{CreateFloppy}{entryImage}->get_text()) { &show_err_msg('invalidname'); }
             else {
-                $gui{d}{CreateFloppy}->hide;
+                $gui{d}{CreateFloppy}{dialog}->hide;
                 my ($vol, $dir, $file) = &rsplitpath($gui{d}{CreateFloppy}{entryImage}->get_text());
                 my $alloc = ['Fixed'];
                 $alloc = ['Fixed', 'Formatted'] if ($gui{d}{CreateFloppy}{checkFAT12}->get_active());
@@ -437,9 +441,9 @@ sub show_dialog_create_floppy {
                 &$callback($gui{d}{CreateFloppy}, {IMedium => $IMedium, type => 'Floppy'}) if ($callback);
             }
         }
-        else { $gui{d}{CreateFloppy}->hide; }
+        else { $gui{d}{CreateFloppy}{dialog}->hide; }
 
-    } until (!$gui{d}{CreateFloppy}->get_visible());
+    } until (!$gui{d}{CreateFloppy}{dialog}->get_visible());
 }
 
 # Displays the create a new hard disk dialog. Creates & attaches based on options
@@ -455,13 +459,14 @@ sub show_dialog_create_hd {
     $gui{d}{CreateHD}{sbSize}->set_value(8192.00);
 
     do {
-        my $response = $gui{d}{CreateHD}->run;
+        $gui{d}{CreateHD}{dialog}->show_all();
+        my $response = $gui{d}{CreateHD}{dialog}->run();
 
         if ($response eq 'ok') {
             # No validation needed on other entries
             if (!$gui{d}{CreateHD}{entryImage}->get_text()) { &show_err_msg('invalidname'); }
             else {
-                $gui{d}{CreateHD}->hide;
+                $gui{d}{CreateHD}{dialog}->hide;
                 my ($vol, $dir, $file) = &rsplitpath($gui{d}{CreateHD}{entryImage}->get_text());
 
                 my %newhd = (diskname   => $file,
@@ -480,9 +485,9 @@ sub show_dialog_create_hd {
                 &{$$data{callback}}($gui{d}{CreateHD}, {IMedium => $IMedium, type => 'HardDisk'}) if ($$data{callback});
             }
         }
-        else { $gui{d}{CreateHD}->hide; }
+        else { $gui{d}{CreateHD}{dialog}->hide; }
 
-    } until (!$gui{d}{CreateHD}->get_visible());
+    } until (!$gui{d}{CreateHD}{dialog}->get_visible());
 }
 
 1;
