@@ -80,12 +80,6 @@ sub SOAP::Serializer::as_AutostopType {
     return [$name, {'xsi:type' => 'vbox:AutostopType', %$attr}, $value];
 }
 
-sub SOAP::Serializer::as_BIOSBootMenuMode {
-    my $self = shift;
-    my ($value, $name, $type, $attr) = @_;
-    return [$name, {'xsi:type' => 'vbox:BIOSBootMenuMode', %$attr}, $value];
-}
-
 sub SOAP::Serializer::as_BandwidthGroupType {
     my $self = shift;
     my ($value, $name, $type, $attr) = @_;
@@ -104,10 +98,10 @@ sub SOAP::Serializer::as_CPUArchitecture {
     return [$name, {'xsi:type' => 'vbox:CPUArchitecture', %$attr}, $value];
 }
 
-sub SOAP::Serializer::as_CPUPropertyType {
+sub SOAP::Serializer::as_CPUPropertyTypeX86 {
     my $self = shift;
     my ($value, $name, $type, $attr) = @_;
-    return [$name, {'xsi:type' => 'vbox:CPUPropertyType', %$attr}, $value];
+    return [$name, {'xsi:type' => 'vbox:CPUPropertyTypeX86', %$attr}, $value];
 }
 
 sub SOAP::Serializer::as_ChipsetType {
@@ -260,6 +254,12 @@ sub SOAP::Serializer::as_FileSharingMode {
     return [$name, {'xsi:type' => 'vbox:FileSharingMode', %$attr}, $value];
 }
 
+sub SOAP::Serializer::as_FirmwareBootMenuMode {
+    my $self = shift;
+    my ($value, $name, $type, $attr) = @_;
+    return [$name, {'xsi:type' => 'vbox:FirmwareBootMenuMode', %$attr}, $value];
+}
+
 sub SOAP::Serializer::as_FirmwareType {
     my $self = shift;
     my ($value, $name, $type, $attr) = @_;
@@ -284,6 +284,12 @@ sub SOAP::Serializer::as_GraphicsControllerType {
     return [$name, {'xsi:type' => 'vbox:GraphicsControllerType', %$attr}, $value];
 }
 
+sub SOAP::Serializer::as_GraphicsFeature {
+    my $self = shift;
+    my ($value, $name, $type, $attr) = @_;
+    return [$name, {'xsi:type' => 'vbox:GraphicsFeature', %$attr}, $value];
+}
+
 sub SOAP::Serializer::as_GuestDebugIoProvider {
     my $self = shift;
     my ($value, $name, $type, $attr) = @_;
@@ -362,6 +368,12 @@ sub SOAP::Serializer::as_MediumVariant {
     return [$name, {'xsi:type' => 'vbox:MediumVariant', %$attr}, $value];
 }
 
+sub SOAP::Serializer::as_MetricType {
+    my $self = shift;
+    my ($value, $name, $type, $attr) = @_;
+    return [$name, {'xsi:type' => 'vbox:MetricType', %$attr}, $value];
+}
+
 sub SOAP::Serializer::as_NATProtocol {
     my $self = shift;
     my ($value, $name, $type, $attr) = @_;
@@ -398,6 +410,12 @@ sub SOAP::Serializer::as_PartitionTableType {
     return [$name, {'xsi:type' => 'vbox:PartitionTableType', %$attr}, $value];
 }
 
+sub SOAP::Serializer::as_PlatformArchitecture {
+    my $self = shift;
+    my ($value, $name, $type, $attr) = @_;
+    return [$name, {'xsi:type' => 'vbox:PlatformArchitecture', %$attr}, $value];
+}
+
 sub SOAP::Serializer::as_PointingHIDType {
     my $self = shift;
     my ($value, $name, $type, $attr) = @_;
@@ -512,6 +530,12 @@ sub SOAP::Serializer::as_StorageControllerType {
     return [$name, {'xsi:type' => 'vbox:StorageControllerType', %$attr}, $value];
 }
 
+sub SOAP::Serializer::as_SymlinkPolicy {
+    my $self = shift;
+    my ($value, $name, $type, $attr) = @_;
+    return [$name, {'xsi:type' => 'vbox:SymlinkPolicy', %$attr}, $value];
+}
+
 sub SOAP::Serializer::as_SymlinkReadFlag {
     my $self = shift;
     my ($value, $name, $type, $attr) = @_;
@@ -566,6 +590,12 @@ sub SOAP::Serializer::as_VBoxEventType {
     return [$name, {'xsi:type' => 'vbox:VBoxEventType', %$attr}, $value];
 }
 
+sub SOAP::Serializer::as_VMExecutionEngine {
+    my $self = shift;
+    my ($value, $name, $type, $attr) = @_;
+    return [$name, {'xsi:type' => 'vbox:VMExecutionEngine', %$attr}, $value];
+}
+
 sub SOAP::Serializer::as_VMProcPriority {
     my $self = shift;
     my ($value, $name, $type, $attr) = @_;
